@@ -4,42 +4,32 @@
  *  Galileo E1 Signals
  * \author Luis Esteve, 2012. luis(at)epsilon-formacion.com
  *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
  *
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
-#ifndef GNSS_SDR_GALILEO_E1_PCPS_AMBIGUOUS_ACQUISITION_H_
-#define GNSS_SDR_GALILEO_E1_PCPS_AMBIGUOUS_ACQUISITION_H_
+#ifndef GNSS_SDR_GALILEO_E1_PCPS_AMBIGUOUS_ACQUISITION_H
+#define GNSS_SDR_GALILEO_E1_PCPS_AMBIGUOUS_ACQUISITION_H
 
 #include "acq_conf.h"
-#include "acquisition_interface.h"
+#include "channel_fsm.h"
 #include "complex_byte_to_float_x2.h"
 #include "gnss_synchro.h"
 #include "pcps_acquisition.h"
 #include <gnuradio/blocks/float_to_complex.h>
-#include <volk_gnsssdr/volk_gnsssdr.h>
+#include <memory>
 #include <string>
+#include <vector>
 
 
 class ConfigurationInterface;
@@ -51,12 +41,13 @@ class ConfigurationInterface;
 class GalileoE1PcpsAmbiguousAcquisition : public AcquisitionInterface
 {
 public:
-    GalileoE1PcpsAmbiguousAcquisition(ConfigurationInterface* configuration,
+    GalileoE1PcpsAmbiguousAcquisition(
+        const ConfigurationInterface* configuration,
         const std::string& role,
         unsigned int in_streams,
         unsigned int out_streams);
 
-    virtual ~GalileoE1PcpsAmbiguousAcquisition();
+    ~GalileoE1PcpsAmbiguousAcquisition() = default;
 
     inline std::string role() override
     {
@@ -91,7 +82,20 @@ public:
     /*!
      * \brief Set acquisition channel unique ID
      */
-    void set_channel(unsigned int channel) override;
+    inline void set_channel(unsigned int channel) override
+    {
+        channel_ = channel;
+        acquisition_->set_channel(channel_);
+    }
+
+    /*!
+     * \brief Set channel fsm associated to this acquisition instance
+     */
+    inline void set_channel_fsm(std::weak_ptr<ChannelFsm> channel_fsm) override
+    {
+        channel_fsm_ = channel_fsm;
+        acquisition_->set_channel_fsm(channel_fsm);
+    }
 
     /*!
      * \brief Set statistics threshold of PCPS algorithm
@@ -108,6 +112,11 @@ public:
      */
     void set_doppler_step(unsigned int doppler_step) override;
 
+    /*!
+     * \brief Set Doppler center for the grid search
+     */
+    void set_doppler_center(int doppler_center) override;
+
     /*!
      * \brief Initializes acquisition algorithm.
      */
@@ -141,39 +150,33 @@ public:
     /*!
      * \brief Sets the resampler latency to account it in the acquisition code delay estimation
      */
-
     void set_resampler_latency(uint32_t latency_samples) override;
 
-
 private:
-    ConfigurationInterface* configuration_;
-    Acq_Conf acq_parameters_;
     pcps_acquisition_sptr acquisition_;
+    std::vector<std::complex<float>> code_;
+    std::weak_ptr<ChannelFsm> channel_fsm_;
     gr::blocks::float_to_complex::sptr float_to_complex_;
     complex_byte_to_float_x2_sptr cbyte_to_float_x2_;
-    size_t item_size_;
+    Gnss_Synchro* gnss_synchro_;
+    const ConfigurationInterface* configuration_;
+    Acq_Conf acq_parameters_;
     std::string item_type_;
+    std::string dump_filename_;
+    std::string role_;
+    int64_t fs_in_;
+    size_t item_size_;
+    float threshold_;
+    int doppler_center_;
     unsigned int vector_length_;
     unsigned int code_length_;
-    bool bit_transition_flag_;
-    bool use_CFAR_algorithm_flag_;
-    bool acquire_pilot_;
     unsigned int channel_;
-    float threshold_;
     unsigned int doppler_max_;
     unsigned int doppler_step_;
     unsigned int sampled_ms_;
-    unsigned int max_dwells_;
-    int64_t fs_in_;
-    bool dump_;
-    bool blocking_;
-    std::string dump_filename_;
-    std::complex<float>* code_;
-    Gnss_Synchro* gnss_synchro_;
-    std::string role_;
     unsigned int in_streams_;
     unsigned int out_streams_;
-    float calculate_threshold(float pfa);
+    bool acquire_pilot_;
 };
 
-#endif /* GNSS_SDR_GALILEO_E1_PCPS_AMBIGUOUS_ACQUISITION_H_ */
+#endif  // GNSS_SDR_GALILEO_E1_PCPS_AMBIGUOUS_ACQUISITION_H
