@@ -4,40 +4,31 @@
  *  GPS L1 C/A signals
  * \author Marc Molina, 2013. marc.molina.pena(at)gmail.com
  *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
  *
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
-#ifndef GNSS_SDR_GPS_L1_CA_TONG_ACQUISITION_H_
-#define GNSS_SDR_GPS_L1_CA_TONG_ACQUISITION_H_
+#ifndef GNSS_SDR_GPS_L1_CA_TONG_ACQUISITION_H
+#define GNSS_SDR_GPS_L1_CA_TONG_ACQUISITION_H
 
-#include "acquisition_interface.h"
+#include "channel_fsm.h"
 #include "configuration_interface.h"
 #include "gnss_synchro.h"
 #include "pcps_tong_acquisition_cc.h"
 #include <gnuradio/blocks/stream_to_vector.h>
+#include <memory>
 #include <string>
+#include <vector>
 
 class ConfigurationInterface;
 
@@ -48,12 +39,12 @@ class ConfigurationInterface;
 class GpsL1CaPcpsTongAcquisition : public AcquisitionInterface
 {
 public:
-    GpsL1CaPcpsTongAcquisition(ConfigurationInterface* configuration,
+    GpsL1CaPcpsTongAcquisition(const ConfigurationInterface* configuration,
         const std::string& role,
         unsigned int in_streams,
         unsigned int out_streams);
 
-    virtual ~GpsL1CaPcpsTongAcquisition();
+    ~GpsL1CaPcpsTongAcquisition() = default;
 
     inline std::string role() override
     {
@@ -88,7 +79,20 @@ public:
     /*!
      * \brief Set acquisition channel unique ID
      */
-    void set_channel(unsigned int channel) override;
+    inline void set_channel(unsigned int channel) override
+    {
+        channel_ = channel;
+        acquisition_cc_->set_channel(channel_);
+    }
+
+    /*!
+     * \brief Set channel fsm associated to this acquisition instance
+     */
+    inline void set_channel_fsm(std::weak_ptr<ChannelFsm> channel_fsm) override
+    {
+        channel_fsm_ = channel_fsm;
+        acquisition_cc_->set_channel_fsm(channel_fsm);
+    }
 
     /*!
      * \brief Set statistics threshold of TONG algorithm
@@ -138,31 +142,32 @@ public:
     void set_resampler_latency(uint32_t latency_samples __attribute__((unused))) override{};
 
 private:
-    ConfigurationInterface* configuration_;
+    float calculate_threshold(float pfa);
+
+    const ConfigurationInterface* configuration_;
     pcps_tong_acquisition_cc_sptr acquisition_cc_;
     gr::blocks::stream_to_vector::sptr stream_to_vector_;
-    size_t item_size_;
+    std::weak_ptr<ChannelFsm> channel_fsm_;
+    std::vector<std::complex<float>> code_;
+    Gnss_Synchro* gnss_synchro_;
     std::string item_type_;
+    std::string dump_filename_;
+    std::string role_;
+    int64_t fs_in_;
+    size_t item_size_;
+    float threshold_;
     unsigned int vector_length_;
     unsigned int code_length_;
     unsigned int channel_;
-    float threshold_;
     unsigned int doppler_max_;
     unsigned int doppler_step_;
     unsigned int sampled_ms_;
     unsigned int tong_init_val_;
     unsigned int tong_max_val_;
     unsigned int tong_max_dwells_;
-    int64_t fs_in_;
-    bool dump_;
-    std::string dump_filename_;
-    std::complex<float>* code_;
-    Gnss_Synchro* gnss_synchro_;
-    std::string role_;
     unsigned int in_streams_;
     unsigned int out_streams_;
-
-    float calculate_threshold(float pfa);
+    bool dump_;
 };
 
-#endif /* GNSS_SDR_GPS_L1_CA_TONG_ACQUISITION_H_ */
+#endif  // GNSS_SDR_GPS_L1_CA_TONG_ACQUISITION_H
