@@ -4,9 +4,9 @@
  * \author Carlos Aviles, 2010. carlos.avilesr(at)googlemail.com
  *         Luis Esteve, 2011. luis(at)epsilon-formacion.com
  *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2019  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
@@ -15,7 +15,7 @@
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 #include "channel.h"
@@ -29,20 +29,18 @@
 #include <utility>  // for std::move
 
 
-Channel::Channel(ConfigurationInterface* configuration, uint32_t channel, const std::shared_ptr<AcquisitionInterface>& acq,
-    const std::shared_ptr<TrackingInterface>& trk, const std::shared_ptr<TelemetryDecoderInterface>& nav,
-    const std::string& role, const std::string& implementation, const std::shared_ptr<Concurrent_Queue<pmt::pmt_t> >& queue)
+Channel::Channel(const ConfigurationInterface* configuration, uint32_t channel, std::shared_ptr<AcquisitionInterface> acq,
+    std::shared_ptr<TrackingInterface> trk, std::shared_ptr<TelemetryDecoderInterface> nav,
+    const std::string& role, const std::string& signal_str, Concurrent_Queue<pmt::pmt_t>* queue)
 {
-    acq_ = acq;
-    trk_ = trk;
-    nav_ = nav;
+    acq_ = std::move(acq);
+    trk_ = std::move(trk);
+    nav_ = std::move(nav);
     role_ = role;
-    implementation_ = implementation;
     channel_ = channel;
-    queue_ = queue;
     channel_fsm_ = std::make_shared<ChannelFsm>();
 
-    flag_enable_fpga = configuration->property("GNSS-SDR.enable_FPGA", false);
+    flag_enable_fpga_ = configuration->property("GNSS-SDR.enable_FPGA", false);
 
     acq_->set_channel(channel_);
     acq_->set_channel_fsm(channel_fsm_);
@@ -57,20 +55,20 @@ Channel::Channel(ConfigurationInterface* configuration, uint32_t channel, const
     // Provide a warning to the user about the change of parameter name
     if (channel_ == 0)
         {
-            int64_t deprecation_warning = configuration->property("GNSS-SDR.internal_fs_hz", 0);
+            const int64_t deprecation_warning = configuration->property("GNSS-SDR.internal_fs_hz", 0);
             if (deprecation_warning != 0)
                 {
-                    std::cout << "WARNING: The global parameter name GNSS-SDR.internal_fs_hz has been DEPRECATED." << std::endl;
-                    std::cout << "WARNING: Please replace it by GNSS-SDR.internal_fs_sps in your configuration file." << std::endl;
+                    std::cout << "WARNING: The global parameter name GNSS-SDR.internal_fs_hz has been DEPRECATED.\n";
+                    std::cout << "WARNING: Please replace it by GNSS-SDR.internal_fs_sps in your configuration file.\n";
                 }
         }
 
     // IMPORTANT: Do not change the order between set_doppler_step and set_threshold
 
-    uint32_t doppler_step = configuration->property("Acquisition_" + implementation_ + std::to_string(channel_) + ".doppler_step", 0);
+    uint32_t doppler_step = configuration->property("Acquisition_" + signal_str + std::to_string(channel_) + ".doppler_step", 0);
     if (doppler_step == 0)
         {
-            doppler_step = configuration->property("Acquisition_" + implementation_ + ".doppler_step", 500);
+            doppler_step = configuration->property("Acquisition_" + signal_str + ".doppler_step", 500);
         }
     if (FLAGS_doppler_step != 0)
         {
@@ -80,36 +78,36 @@ Channel::Channel(ConfigurationInterface* configuration, uint32_t channel, const
 
     acq_->set_doppler_step(doppler_step);
 
-    float threshold = configuration->property("Acquisition_" + implementation_ + std::to_string(channel_) + ".threshold", 0.0);
+    float threshold = configuration->property("Acquisition_" + signal_str + std::to_string(channel_) + ".threshold", static_cast<float>(0.0));
     if (threshold == 0.0)
         {
-            threshold = configuration->property("Acquisition_" + implementation_ + ".threshold", 0.0);
+            threshold = configuration->property("Acquisition_" + signal_str + ".threshold", static_cast<float>(0.0));
         }
 
     acq_->set_threshold(threshold);
 
     acq_->init();
 
-    repeat_ = configuration->property("Acquisition_" + implementation_ + std::to_string(channel_) + ".repeat_satellite", false);
+    repeat_ = configuration->property("Acquisition_" + signal_str + std::to_string(channel_) + ".repeat_satellite", false);
     DLOG(INFO) << "Channel " << channel_ << " satellite repeat = " << repeat_;
 
     channel_fsm_->set_acquisition(acq_);
     channel_fsm_->set_tracking(trk_);
     channel_fsm_->set_telemetry(nav_);
     channel_fsm_->set_channel(channel_);
-    channel_fsm_->set_queue(queue_);
+    channel_fsm_->set_queue(queue);
 
     connected_ = false;
 
-    gnss_signal_ = Gnss_Signal(implementation_);
+    gnss_signal_ = Gnss_Signal(signal_str);
 
-    channel_msg_rx = channel_msg_receiver_make_cc(channel_fsm_, repeat_);
+    channel_msg_rx_ = channel_msg_receiver_make_cc(channel_fsm_, repeat_);
 }
 
 
 void Channel::connect(gr::top_block_sptr top_block)
 {
-    if (!flag_enable_fpga)
+    if (!flag_enable_fpga_)
         {
             acq_->connect(top_block);
         }
@@ -124,11 +122,11 @@ void Channel::connect(gr::top_block_sptr top_block)
     DLOG(INFO) << "tracking -> telemetry_decoder";
 
     // Message ports
-    if (!flag_enable_fpga)
+    if (!flag_enable_fpga_)
         {
-            top_block->msg_connect(acq_->get_right_block(), pmt::mp("events"), channel_msg_rx, pmt::mp("events"));
+            top_block->msg_connect(acq_->get_right_block(), pmt::mp("events"), channel_msg_rx_, pmt::mp("events"));
         }
-    top_block->msg_connect(trk_->get_right_block(), pmt::mp("events"), channel_msg_rx, pmt::mp("events"));
+    top_block->msg_connect(trk_->get_right_block(), pmt::mp("events"), channel_msg_rx_, pmt::mp("events"));
 
     connected_ = true;
 }
@@ -143,7 +141,7 @@ void Channel::disconnect(gr::top_block_sptr top_block)
         }
 
     top_block->disconnect(trk_->get_right_block(), 0, nav_->get_left_block(), 0);
-    if (!flag_enable_fpga)
+    if (!flag_enable_fpga_)
         {
             acq_->disconnect(top_block);
         }
@@ -151,11 +149,11 @@ void Channel::disconnect(gr::top_block_sptr top_block)
     nav_->disconnect(top_block);
 
     top_block->msg_disconnect(nav_->get_left_block(), pmt::mp("telemetry_to_trk"), trk_->get_right_block(), pmt::mp("telemetry_to_trk"));
-    if (!flag_enable_fpga)
+    if (!flag_enable_fpga_)
         {
-            top_block->msg_disconnect(acq_->get_right_block(), pmt::mp("events"), channel_msg_rx, pmt::mp("events"));
+            top_block->msg_disconnect(acq_->get_right_block(), pmt::mp("events"), channel_msg_rx_, pmt::mp("events"));
         }
-    top_block->msg_disconnect(trk_->get_right_block(), pmt::mp("events"), channel_msg_rx, pmt::mp("events"));
+    top_block->msg_disconnect(trk_->get_right_block(), pmt::mp("events"), channel_msg_rx_, pmt::mp("events"));
     connected_ = false;
 }
 
@@ -175,7 +173,7 @@ gr::basic_block_sptr Channel::get_left_block_trk()
 
 gr::basic_block_sptr Channel::get_left_block_acq()
 {
-    if (flag_enable_fpga)
+    if (flag_enable_fpga_)
         {
             LOG(ERROR) << "Enabled FPGA and called get_left_block() in channel interface";
         }
@@ -191,16 +189,16 @@ gr::basic_block_sptr Channel::get_right_block()
 
 void Channel::set_signal(const Gnss_Signal& gnss_signal)
 {
-    std::lock_guard<std::mutex> lk(mx);
+    std::lock_guard<std::mutex> lk(mx_);
     gnss_signal_ = gnss_signal;
-    std::string str_aux = gnss_signal_.get_signal_str();
+    const std::string str_aux = gnss_signal_.get_signal_str();
     gnss_synchro_.Signal[0] = str_aux[0];
     gnss_synchro_.Signal[1] = str_aux[1];
     gnss_synchro_.Signal[2] = '\0';  // make sure that string length is only two characters
     gnss_synchro_.PRN = gnss_signal_.get_satellite().get_PRN();
     gnss_synchro_.System = gnss_signal_.get_satellite().get_system_short().c_str()[0];
     acq_->set_local_code();
-    if (flag_enable_fpga)
+    if (flag_enable_fpga_)
         {
             trk_->set_gnss_synchro(&gnss_synchro_);
         }
@@ -210,8 +208,8 @@ void Channel::set_signal(const Gnss_Signal& gnss_signal)
 
 void Channel::stop_channel()
 {
-    std::lock_guard<std::mutex> lk(mx);
-    bool result = channel_fsm_->Event_stop_channel();
+    std::lock_guard<std::mutex> lk(mx_);
+    const bool result = channel_fsm_->Event_stop_channel();
     if (!result)
         {
             LOG(WARNING) << "Invalid channel event";
@@ -229,9 +227,9 @@ void Channel::assist_acquisition_doppler(double Carrier_Doppler_hz)
 
 void Channel::start_acquisition()
 {
-    std::lock_guard<std::mutex> lk(mx);
+    std::lock_guard<std::mutex> lk(mx_);
     bool result = false;
-    if (!flag_enable_fpga)
+    if (!flag_enable_fpga_)
         {
             result = channel_fsm_->Event_start_acquisition();
         }
