@@ -4,29 +4,18 @@
  * to a gr_complex (float) stream
  * \author Carles Fernandez-Prades, cfernandez(at)cttc.es
  *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
  *
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 #include "ibyte_to_cshort.h"
@@ -35,24 +24,22 @@
 #include <volk/volk.h>
 
 
-using google::LogMessage;
-
-IbyteToCshort::IbyteToCshort(ConfigurationInterface* configuration, const std::string& role,
-    unsigned int in_streams, unsigned int out_streams) : config_(configuration), role_(role), in_streams_(in_streams), out_streams_(out_streams)
+IbyteToCshort::IbyteToCshort(const ConfigurationInterface* configuration, const std::string& role,
+    unsigned int in_streams, unsigned int out_streams) : role_(role), in_streams_(in_streams), out_streams_(out_streams)
 {
-    std::string default_input_item_type = "byte";
-    std::string default_output_item_type = "cshort";
-    std::string default_dump_filename = "../data/input_filter.dat";
+    const std::string default_input_item_type("byte");
+    const std::string default_output_item_type("cshort");
+    const std::string default_dump_filename("../data/input_filter.dat");
 
     DLOG(INFO) << "role " << role_;
 
-    input_item_type_ = config_->property(role_ + ".input_item_type", default_input_item_type);
+    input_item_type_ = configuration->property(role_ + ".input_item_type", default_input_item_type);
 
-    dump_ = config_->property(role_ + ".dump", false);
-    dump_filename_ = config_->property(role_ + ".dump_filename", default_dump_filename);
+    dump_ = configuration->property(role_ + ".dump", false);
+    dump_filename_ = configuration->property(role_ + ".dump_filename", default_dump_filename);
     inverted_spectrum = configuration->property(role + ".inverted_spectrum", false);
 
-    size_t item_size = sizeof(lv_16sc_t);
+    const size_t item_size = sizeof(lv_16sc_t);
 
     interleaved_byte_to_complex_short_ = make_interleaved_byte_to_complex_short();
 
@@ -78,9 +65,6 @@ IbyteToCshort::IbyteToCshort(ConfigurationInterface* configuration, const std::s
 }
 
 
-IbyteToCshort::~IbyteToCshort() = default;
-
-
 void IbyteToCshort::connect(gr::top_block_sptr top_block)
 {
     if (dump_)
