@@ -3,40 +3,29 @@
  * \brief Implements a multi state notch filter algorithm
  * \author Antonio Ramos (antonio.ramosdet(at)gmail.com)
  *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2019 (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
  *
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 #include "notch_cc.h"
+#include "gnss_sdr_make_unique.h"
 #include <boost/math/distributions/chi_squared.hpp>
-#include <glog/logging.h>
 #include <gnuradio/io_signature.h>
 #include <volk/volk.h>
+#include <algorithm>
 #include <cmath>
 #include <cstring>
 
-using google::LogMessage;
 
 notch_sptr make_notch_filter(float pfa, float p_c_factor,
     int32_t length_, int32_t n_segments_est, int32_t n_segments_reset)
@@ -68,19 +57,11 @@ Notch::Notch(float pfa,
     z_0 = gr_complex(0.0, 0.0);
     boost::math::chi_squared_distribution<float> my_dist_(n_deg_fred);
     thres_ = boost::math::quantile(boost::math::complement(my_dist_, pfa));
-    c_samples = static_cast<gr_complex *>(volk_malloc(length_ * sizeof(gr_complex), volk_get_alignment()));
-    angle_ = static_cast<float *>(volk_malloc(length_ * sizeof(float), volk_get_alignment()));
-    power_spect = static_cast<float *>(volk_malloc(length_ * sizeof(float), volk_get_alignment()));
+    c_samples = volk_gnsssdr::vector<gr_complex>(length_);
+    angle_ = volk_gnsssdr::vector<float>(length_);
+    power_spect = volk_gnsssdr::vector<float>(length_);
     last_out = gr_complex(0.0, 0.0);
-    d_fft = std::unique_ptr<gr::fft::fft_complex>(new gr::fft::fft_complex(length_, true));
-}
-
-
-Notch::~Notch()
-{
-    volk_free(c_samples);
-    volk_free(angle_);
-    volk_free(power_spect);
+    d_fft = std::make_unique<gr::fft::fft_complex>(length_, true);
 }
 
 
@@ -109,9 +90,9 @@ int Notch::general_work(int noutput_items, gr_vector_int &ninput_items __attribu
                 {
                     memcpy(d_fft->get_inbuf(), in, sizeof(gr_complex) * length_);
                     d_fft->execute();
-                    volk_32fc_s32f_power_spectrum_32f(power_spect, d_fft->get_outbuf(), 1.0, length_);
-                    volk_32f_s32f_calc_spectral_noise_floor_32f(&sig2dB, power_spect, 15.0, length_);
-                    sig2lin = std::pow(10.0, (sig2dB / 10.0)) / (static_cast<float>(n_deg_fred));
+                    volk_32fc_s32f_power_spectrum_32f(power_spect.data(), d_fft->get_outbuf(), 1.0, length_);
+                    volk_32f_s32f_calc_spectral_noise_floor_32f(&sig2dB, power_spect.data(), 15.0, length_);
+                    sig2lin = std::pow(10.0F, (sig2dB / 10.0F)) / (static_cast<float>(n_deg_fred));
                     noise_pow_est = (static_cast<float>(n_segments) * noise_pow_est + sig2lin) / (static_cast<float>(n_segments + 1));
                     memcpy(out, in, sizeof(gr_complex) * length_);
                 }
@@ -123,13 +104,13 @@ int Notch::general_work(int noutput_items, gr_vector_int &ninput_items __attribu
                             if (filter_state_ == false)
                                 {
                                     filter_state_ = true;
-                                    last_out = gr_complex(0, 0);
+                                    last_out = gr_complex(0.0, 0.0);
                                 }
-                            volk_32fc_x2_multiply_conjugate_32fc(c_samples, in, (in - 1), length_);
-                            volk_32fc_s32f_atan2_32f(angle_, c_samples, static_cast<float>(1.0), length_);
+                            volk_32fc_x2_multiply_conjugate_32fc(c_samples.data(), in, (in - 1), length_);
+                            volk_32fc_s32f_atan2_32f(angle_.data(), c_samples.data(), static_cast<float>(1.0), length_);
                             for (int32_t aux = 0; aux < length_; aux++)
                                 {
-                                    z_0 = std::exp(gr_complex(0, 1) * (*(angle_ + aux)));
+                                    z_0 = std::exp(gr_complex(0.0, 1.0) * (*(angle_.data() + aux)));
                                     *(out + aux) = *(in + aux) - z_0 * (*(in + aux - 1)) + p_c_factor * z_0 * last_out;
                                     last_out = *(out + aux);
                                 }
