@@ -1,3 +1,35 @@
+/*!
+ * \file rtklib_rtksvr.cc
+ * \brief rtk server functions
+ * \authors <ul>
+ *          <li> 2007-2013, T. Takasu
+ *          <li> 2017, Javier Arribas
+ *          <li> 2017, Carles Fernandez
+ *          </ul>
+ *
+ * This is a derived work from RTKLIB http://www.rtklib.com/
+ * The original source code at https://github.com/tomojitakasu/RTKLIB is
+ * released under the BSD 2-clause license with an additional exclusive clause
+ * that does not apply here. This additional clause is reproduced below:
+ *
+ * " The software package includes some companion executive binaries or shared
+ * libraries necessary to execute APs on Windows. These licenses succeed to the
+ * original ones of these software. "
+ *
+ * Neither the executive binaries nor the shared libraries are required by, used
+ * or included in GNSS-SDR.
+ *
+ * -----------------------------------------------------------------------------
+ * Copyright (C) 2007-2013, T. Takasu
+ * Copyright (C) 2017, Javier Arribas
+ * Copyright (C) 2017, Carles Fernandez
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: BSD-2-Clause
+ *
+ *
+ * -----------------------------------------------------------------------------
+ */
 
 #include "rtklib_rtksvr.h"
 #include "rtklib_preceph.h"
@@ -7,11 +39,12 @@
 #include "rtklib_sbas.h"
 #include "rtklib_solution.h"
 #include "rtklib_stream.h"
+#include <cstring>
 
 /* write solution header to output stream ------------------------------------*/
 void writesolhead(stream_t *stream, const solopt_t *solopt)
 {
-    unsigned char buff[1024];
+    unsigned char buff[MAXSOLMSG];
     int n;
     n = outsolheads(buff, solopt);
     strwrite(stream, buff, n);
@@ -34,9 +67,10 @@ void saveoutbuf(rtksvr_t *svr, unsigned char *buff, int n, int index)
 /* write solution to output stream -------------------------------------------*/
 void writesol(rtksvr_t *svr, int index)
 {
-    solopt_t solopt = solopt_default;
-    unsigned char buff[1024];
-    int i, n;
+    solopt_t solopt = SOLOPT_DEFAULT;
+    unsigned char buff[MAXSOLMSG];
+    int i;
+    int n;
 
     tracet(4, "writesol: index=%d\n", index);
 
@@ -75,19 +109,25 @@ void writesol(rtksvr_t *svr, int index)
 /* update navigation data ----------------------------------------------------*/
 void updatenav(nav_t *nav)
 {
-    int i, j;
+    int i;
+    int j;
     for (i = 0; i < MAXSAT; i++)
-        for (j = 0; j < NFREQ; j++)
-            {
-                nav->lam[i][j] = satwavelen(i + 1, j, nav);
-            }
+        {
+            for (j = 0; j < NFREQ; j++)
+                {
+                    nav->lam[i][j] = satwavelen(i + 1, j, nav);
+                }
+        }
 }
 
 
 /* update glonass frequency channel number in raw data struct ----------------*/
 void updatefcn(rtksvr_t *svr)
 {
-    int i, j, sat, frq;
+    int i;
+    int j;
+    int sat;
+    int frq;
 
     for (i = 0; i < MAXPRNGLO; i++)
         {
@@ -95,14 +135,23 @@ void updatefcn(rtksvr_t *svr)
 
             for (j = 0, frq = -999; j < 3; j++)
                 {
-                    if (svr->raw[j].nav.geph[i].sat != sat) continue;
+                    if (svr->raw[j].nav.geph[i].sat != sat)
+                        {
+                            continue;
+                        }
                     frq = svr->raw[j].nav.geph[i].frq;
                 }
-            if (frq < -7 || frq > 6) continue;
+            if (frq < -7 || frq > 6)
+                {
+                    continue;
+                }
 
             for (j = 0; j < 3; j++)
                 {
-                    if (svr->raw[j].nav.geph[i].sat == sat) continue;
+                    if (svr->raw[j].nav.geph[i].sat == sat)
+                        {
+                            continue;
+                        }
                     svr->raw[j].nav.geph[i].sat = sat;
                     svr->raw[j].nav.geph[i].frq = frq;
                 }
@@ -114,11 +163,22 @@ void updatefcn(rtksvr_t *svr)
 void updatesvr(rtksvr_t *svr, int ret, obs_t *obs, nav_t *nav, int sat,
     sbsmsg_t *sbsmsg, int index, int iobs)
 {
-    eph_t *eph1, *eph2, *eph3;
-    geph_t *geph1, *geph2, *geph3;
+    eph_t *eph1;
+    eph_t *eph2;
+    eph_t *eph3;
+    geph_t *geph1;
+    geph_t *geph2;
+    geph_t *geph3;
     // gtime_t tof;
-    double pos[3], del[3] = {0}, dr[3];
-    int i, n = 0, prn, sbssat = svr->rtk.opt.sbassatsel, sys, iode;
+    double pos[3];
+    double del[3] = {0};
+    double dr[3];
+    int i;
+    int n = 0;
+    int prn;
+    int sbssat = svr->rtk.opt.sbassatsel;
+    int sys;
+    int iode;
 
     tracet(4, "updatesvr: ret=%d sat=%2d index=%d\n", ret, sat, index);
 
@@ -129,7 +189,10 @@ void updatesvr(rtksvr_t *svr, int ret, obs_t *obs, nav_t *nav, int sat,
                     for (i = 0; i < obs->n; i++)
                         {
                             if (svr->rtk.opt.exsats[obs->data[i].sat - 1] == 1 ||
-                                !(satsys(obs->data[i].sat, nullptr) & svr->rtk.opt.navsys)) continue;
+                                !(satsys(obs->data[i].sat, nullptr) & svr->rtk.opt.navsys))
+                                {
+                                    continue;
+                                }
                             svr->obs[index][iobs].data[n] = obs->data[i];
                             svr->obs[index][iobs].data[n++].rcv = index + 1;
                         }
@@ -188,7 +251,10 @@ void updatesvr(rtksvr_t *svr, int ret, obs_t *obs, nav_t *nav, int sat,
                         }
                     else
                         {
-                            for (i = 0; i < MAXSBSMSG - 1; i++) svr->sbsmsg[i] = svr->sbsmsg[i + 1];
+                            for (i = 0; i < MAXSBSMSG - 1; i++)
+                                {
+                                    svr->sbsmsg[i] = svr->sbsmsg[i + 1];
+                                }
                             svr->sbsmsg[i] = *sbsmsg;
                         }
                     sbsupdatecorr(sbsmsg, &svr->nav);
@@ -199,12 +265,30 @@ void updatesvr(rtksvr_t *svr, int ret, obs_t *obs, nav_t *nav, int sat,
         { /* ion/utc parameters */
             if (svr->navsel == index || svr->navsel >= 3)
                 {
-                    for (i = 0; i < 8; i++) svr->nav.ion_gps[i] = nav->ion_gps[i];
-                    for (i = 0; i < 4; i++) svr->nav.utc_gps[i] = nav->utc_gps[i];
-                    for (i = 0; i < 4; i++) svr->nav.ion_gal[i] = nav->ion_gal[i];
-                    for (i = 0; i < 4; i++) svr->nav.utc_gal[i] = nav->utc_gal[i];
-                    for (i = 0; i < 8; i++) svr->nav.ion_qzs[i] = nav->ion_qzs[i];
-                    for (i = 0; i < 4; i++) svr->nav.utc_qzs[i] = nav->utc_qzs[i];
+                    for (i = 0; i < 8; i++)
+                        {
+                            svr->nav.ion_gps[i] = nav->ion_gps[i];
+                        }
+                    for (i = 0; i < 4; i++)
+                        {
+                            svr->nav.utc_gps[i] = nav->utc_gps[i];
+                        }
+                    for (i = 0; i < 4; i++)
+                        {
+                            svr->nav.ion_gal[i] = nav->ion_gal[i];
+                        }
+                    for (i = 0; i < 4; i++)
+                        {
+                            svr->nav.utc_gal[i] = nav->utc_gal[i];
+                        }
+                    for (i = 0; i < 8; i++)
+                        {
+                            svr->nav.ion_qzs[i] = nav->ion_qzs[i];
+                        }
+                    for (i = 0; i < 4; i++)
+                        {
+                            svr->nav.utc_qzs[i] = nav->utc_qzs[i];
+                        }
                     svr->nav.leaps = nav->leaps;
                 }
             svr->nmsg[index][2]++;
@@ -247,7 +331,10 @@ void updatesvr(rtksvr_t *svr, int ret, obs_t *obs, nav_t *nav, int sat,
         { /* ssr message */
             for (i = 0; i < MAXSAT; i++)
                 {
-                    if (!svr->rtcm[index].ssr[i].update) continue;
+                    if (!svr->rtcm[index].ssr[i].update)
+                        {
+                            continue;
+                        }
                     svr->rtcm[index].ssr[i].update = 0;
 
                     iode = svr->rtcm[index].ssr[i].iode;
@@ -292,7 +379,10 @@ int decoderaw(rtksvr_t *svr, int index)
     obs_t *obs;
     nav_t *nav;
     sbsmsg_t *sbsmsg = nullptr;
-    int i, ret = 0, sat, fobs = 0;
+    int i;
+    int ret = 0;
+    int sat;
+    int fobs = 0;
 
     tracet(4, "decoderaw: index=%d\n", index);
 
@@ -318,7 +408,7 @@ int decoderaw(rtksvr_t *svr, int index)
             else
                 {
                     // Disabled !!
-                    //ret = input_raw(svr->raw+index, svr->format[index], svr->buff[index][i]);
+                    // ret = input_raw(svr->raw+index, svr->format[index], svr->buff[index][i]);
                     obs = &svr->raw[index].obs;
                     nav = &svr->raw[index].nav;
                     sat = svr->raw[index].ephsat;
@@ -332,15 +422,22 @@ int decoderaw(rtksvr_t *svr, int index)
                 }
 #endif
             /* update rtk server */
-            if (ret > 0) updatesvr(svr, ret, obs, nav, sat, sbsmsg, index, fobs);
+            if (ret > 0)
+                {
+                    updatesvr(svr, ret, obs, nav, sat, sbsmsg, index, fobs);
+                }
 
             /* observation data received */
             if (ret == 1)
                 {
                     if (fobs < MAXOBSBUF)
-                        fobs++;
+                        {
+                            fobs++;
+                        }
                     else
-                        svr->prcout++;
+                        {
+                            svr->prcout++;
+                        }
                 }
         }
     svr->nb[index] = 0;
@@ -354,31 +451,7 @@ int decoderaw(rtksvr_t *svr, int index)
 /* decode download file ------------------------------------------------------*/
 void decodefile(rtksvr_t *svr, int index)
 {
-    int i = 0;
-    char glo_fcn[MAXPRNGLO + 1];
-
-    // Allocate space for GLONASS frequency channels depending on availability
-    for (i = 0; i < MAXPRNGLO + 1; i++)
-        glo_fcn[i] = '0';
-    pcv_t pcvt0[MAXSAT] = {{0, {'0'}, {'0'}, {0, 0.0}, {0, 0.0}, {{0.0}, {0.0}}, {{0.0}, {0.0}}}};
-    sbsfcorr_t sbsfcorr0 = {{0, 0.0}, 0.0, 0.0, 0.0, 0, 0, 0};
-    sbslcorr_t sbslcorr0 = {{0, 0.0}, 0, {0.0}, {0.0}, 0.0, 0.0};
-    sbssat_t sbssat0 = {0, 0, 0, {{0, sbsfcorr0, sbslcorr0}}};
-    sbsigp_t sbsigp0[MAXNIGP] = {{{0, 0.0}, 0, 0, 0, 0.0}};
-    sbsion_t sbsion0[MAXBAND + 1] = {{0, 0, {*sbsigp0}}};
-    dgps_t dgps0[MAXSAT] = {{{0, 0.0}, 0.0, 0.0, 0, 0.0}};
-    ssr_t ssr0[MAXSAT] = {{{{0, 0.0}}, {0.0}, {0}, 0, 0, 0, 0, {0.0}, {0.0}, {0.0}, 0.0, {0.0}, {0.0}, {0.0}, 0.0, 0.0, '0'}};
-    lexeph_t lexeph0[MAXSAT] = {{{0, 0.0}, {0, 0.0}, 0, 0, 0, {0.0}, {0.0}, {0.0}, {0.0}, 0.0, 0.0, 0.0, {0.0}}};
-    stec_t stec0[MAXSTA] = {{{0, 0.0}, 0, 0.0, 0.0, {0.0}, 0}};
-    trop_t trop0[MAXSTA] = {{{0, 0.0}, {0.0}, {0.0}}};
-    pppcorr_t pppcorr0 = {0, {{0}, {0}}, {{0.0}, {0.0}}, {0}, {0}, {0}, {0}, {stec0}, {trop0}};
-
-    nav_t nav = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr,
-        {0, 0, (erpd_t *){nullptr}}, {0.0}, {0.0}, {0.0}, {0.0}, {0.0}, {0.0}, {0.0}, {0.0},
-        {0.0}, {0.0}, {0.0}, {0.0}, 0, {{0.0}, {0.0}}, {{0.0}, {0.0}}, {{{0.0}}, {{0.0}}, {{0.0}}},
-        {0.0}, {0.0}, {*glo_fcn}, {*pcvt0}, sbssat0, {*sbsion0}, {*dgps0}, {*ssr0}, {*lexeph0},
-        {{0, 0.0}, 0.0, {0.0}, {{0.0}, {0.0}}}, pppcorr0};
-
+    nav_t nav{};
     char file[1024];
     int nb;
 
@@ -401,7 +474,6 @@ void decodefile(rtksvr_t *svr, int index)
 
     if (svr->format[index] == STRFMT_SP3)
         { /* precise ephemeris */
-
             /* read sp3 precise ephemeris */
             readsp3(file, &nav, 0);
             if (nav.ne <= 0)
@@ -412,17 +484,20 @@ void decodefile(rtksvr_t *svr, int index)
             /* update precise ephemeris */
             rtksvrlock(svr);
 
-            if (svr->nav.peph) free(svr->nav.peph);
+            if (svr->nav.peph)
+                {
+                    free(svr->nav.peph);
+                }
             svr->nav.ne = svr->nav.nemax = nav.ne;
             svr->nav.peph = nav.peph;
             svr->ftime[index] = utc2gpst(timeget());
-            strcpy(svr->files[index], file);
+            std::strncpy(svr->files[index], file, MAXSTRPATH);
 
             rtksvrunlock(svr);
         }
     else if (svr->format[index] == STRFMT_RNXCLK)
-        { /* precise clock */
-
+        {
+            /* precise clock */
             /* read rinex clock */  // Disabled!!
             if (true /*readrnxc(file, &nav)<=0 */)
                 {
@@ -432,11 +507,14 @@ void decodefile(rtksvr_t *svr, int index)
             /* update precise clock */
             rtksvrlock(svr);
 
-            if (svr->nav.pclk) free(svr->nav.pclk);
+            if (svr->nav.pclk)
+                {
+                    free(svr->nav.pclk);
+                }
             svr->nav.nc = svr->nav.ncmax = nav.nc;
             svr->nav.pclk = nav.pclk;
             svr->ftime[index] = utc2gpst(timeget());
-            strcpy(svr->files[index], file);
+            std::strncpy(svr->files[index], file, MAXSTRPATH);
 
             rtksvrunlock(svr);
         }
@@ -450,9 +528,16 @@ void *rtksvrthread(void *arg)
     obs_t obs;
     obsd_t data[MAXOBS * 2];
     double tt;
-    unsigned int tick, ticknmea;
-    unsigned char *p, *q;
-    int i, j, n, fobs[3] = {0}, cycle, cputime;
+    unsigned int tick;
+    unsigned int ticknmea;
+    unsigned char *p;
+    unsigned char *q;
+    int i;
+    int j;
+    int n;
+    int fobs[3] = {0};
+    int cycle;
+    int cputime;
 
     tracet(3, "rtksvrthread:\n");
 
@@ -554,12 +639,18 @@ void *rtksvrthread(void *arg)
                         }
                     ticknmea = tick;
                 }
-            if ((cputime = static_cast<int>(tickget() - tick)) > 0) svr->cputime = cputime;
+            if ((cputime = static_cast<int>(tickget() - tick)) > 0)
+                {
+                    svr->cputime = cputime;
+                }
 
             /* sleep until next cycle */
             sleepms(svr->cycle - cputime);
         }
-    for (i = 0; i < MAXSTRRTK; i++) strclose(svr->stream + i);
+    for (i = 0; i < MAXSTRRTK; i++)
+        {
+            strclose(svr->stream + i);
+        }
     for (i = 0; i < 3; i++)
         {
             svr->nb[i] = svr->npb[i] = 0;
@@ -567,7 +658,7 @@ void *rtksvrthread(void *arg)
             svr->buff[i] = nullptr;
             free(svr->pbuf[i]);
             svr->pbuf[i] = nullptr;
-            //free_raw (svr->raw +i);
+            // free_raw (svr->raw +i);
             free_rtcm(svr->rtcm + i);
         }
     for (i = 0; i < 2; i++)
@@ -596,28 +687,70 @@ int rtksvrinit(rtksvr_t *svr)
     geph_t geph0 = {0, -1, 0, 0, 0, 0, {0, 0.0}, {0, 0.0}, {0.0}, {0.0}, {0.0},
         0.0, 0.0, 0.0};
     seph_t seph0 = {0, {0, 0.0}, {0, 0.0}, 0, 0, {0.0}, {0.0}, {0.0}, 0.0, 0.0};
-    int i, j;
+    int i;
+    int j;
 
     tracet(3, "rtksvrinit:\n");
 
     svr->state = svr->cycle = svr->nmeacycle = svr->nmeareq = 0;
-    for (i = 0; i < 3; i++) svr->nmeapos[i] = 0.0;
-    svr->buffsize = 0;
-    for (i = 0; i < 3; i++) svr->format[i] = 0;
-    for (i = 0; i < 2; i++) svr->solopt[i] = solopt_default;
-    svr->navsel = svr->nsbs = svr->nsol = 0;
-    rtkinit(&svr->rtk, &prcopt_default);
-    for (i = 0; i < 3; i++) svr->nb[i] = 0;
-    for (i = 0; i < 2; i++) svr->nsb[i] = 0;
-    for (i = 0; i < 3; i++) svr->npb[i] = 0;
-    for (i = 0; i < 3; i++) svr->buff[i] = nullptr;
-    for (i = 0; i < 2; i++) svr->sbuf[i] = nullptr;
-    for (i = 0; i < 3; i++) svr->pbuf[i] = nullptr;
-    for (i = 0; i < MAXSOLBUF; i++) svr->solbuf[i] = sol0;
     for (i = 0; i < 3; i++)
-        for (j = 0; j < 10; j++) svr->nmsg[i][j] = 0;
-    for (i = 0; i < 3; i++) svr->ftime[i] = time0;
-    for (i = 0; i < 3; i++) svr->files[i][0] = '\0';
+        {
+            svr->nmeapos[i] = 0.0;
+        }
+    svr->buffsize = 0;
+    for (i = 0; i < 3; i++)
+        {
+            svr->format[i] = 0;
+        }
+    for (i = 0; i < 2; i++)
+        {
+            svr->solopt[i] = SOLOPT_DEFAULT;
+        }
+    svr->navsel = svr->nsbs = svr->nsol = 0;
+    rtkinit(&svr->rtk, &PRCOPT_DEFAULT);
+    for (i = 0; i < 3; i++)
+        {
+            svr->nb[i] = 0;
+        }
+    for (i = 0; i < 2; i++)
+        {
+            svr->nsb[i] = 0;
+        }
+    for (i = 0; i < 3; i++)
+        {
+            svr->npb[i] = 0;
+        }
+    for (i = 0; i < 3; i++)
+        {
+            svr->buff[i] = nullptr;
+        }
+    for (i = 0; i < 2; i++)
+        {
+            svr->sbuf[i] = nullptr;
+        }
+    for (i = 0; i < 3; i++)
+        {
+            svr->pbuf[i] = nullptr;
+        }
+    for (i = 0; i < MAXSOLBUF; i++)
+        {
+            svr->solbuf[i] = sol0;
+        }
+    for (i = 0; i < 3; i++)
+        {
+            for (j = 0; j < 10; j++)
+                {
+                    svr->nmsg[i][j] = 0;
+                }
+        }
+    for (i = 0; i < 3; i++)
+        {
+            svr->ftime[i] = time0;
+        }
+    for (i = 0; i < 3; i++)
+        {
+            svr->files[i][0] = '\0';
+        }
     svr->moni = nullptr;
     svr->tick = 0;
     svr->thread = 0;  // NOLINT
@@ -630,28 +763,42 @@ int rtksvrinit(rtksvr_t *svr)
             tracet(1, "rtksvrinit: malloc error\n");
             return 0;
         }
-    for (i = 0; i < MAXSAT * 2; i++) svr->nav.eph[i] = eph0;
-    for (i = 0; i < NSATGLO * 2; i++) svr->nav.geph[i] = geph0;
-    for (i = 0; i < NSATSBS * 2; i++) svr->nav.seph[i] = seph0;
+    for (i = 0; i < MAXSAT * 2; i++)
+        {
+            svr->nav.eph[i] = eph0;
+        }
+    for (i = 0; i < NSATGLO * 2; i++)
+        {
+            svr->nav.geph[i] = geph0;
+        }
+    for (i = 0; i < NSATSBS * 2; i++)
+        {
+            svr->nav.seph[i] = seph0;
+        }
     svr->nav.n = MAXSAT * 2;
     svr->nav.ng = NSATGLO * 2;
     svr->nav.ns = NSATSBS * 2;
 
     for (i = 0; i < 3; i++)
-        for (j = 0; j < MAXOBSBUF; j++)
-            {
-                if (!(svr->obs[i][j].data = static_cast<obsd_t *>(malloc(sizeof(obsd_t) * MAXOBS))))
-                    {
-                        tracet(1, "rtksvrinit: malloc error\n");
-                        return 0;
-                    }
-            }
+        {
+            for (j = 0; j < MAXOBSBUF; j++)
+                {
+                    if (!(svr->obs[i][j].data = static_cast<obsd_t *>(malloc(sizeof(obsd_t) * MAXOBS))))
+                        {
+                            tracet(1, "rtksvrinit: malloc error\n");
+                            return 0;
+                        }
+                }
+        }
     for (i = 0; i < 3; i++)
         {
             memset(svr->raw + i, 0, sizeof(raw_t));
             memset(svr->rtcm + i, 0, sizeof(rtcm_t));
         }
-    for (i = 0; i < MAXSTRRTK; i++) strinit(svr->stream + i);
+    for (i = 0; i < MAXSTRRTK; i++)
+        {
+            strinit(svr->stream + i);
+        }
 
     initlock(&svr->lock);
 
@@ -666,16 +813,19 @@ int rtksvrinit(rtksvr_t *svr)
  *-----------------------------------------------------------------------------*/
 void rtksvrfree(rtksvr_t *svr)
 {
-    int i, j;
+    int i;
+    int j;
 
     free(svr->nav.eph);
     free(svr->nav.geph);
     free(svr->nav.seph);
     for (i = 0; i < 3; i++)
-        for (j = 0; j < MAXOBSBUF; j++)
-            {
-                free(svr->obs[i][j].data);
-            }
+        {
+            for (j = 0; j < MAXOBSBUF; j++)
+                {
+                    free(svr->obs[i][j].data);
+                }
+        }
 }
 
 
@@ -735,21 +885,33 @@ int rtksvrstart(rtksvr_t *svr, int cycle, int buffsize, int *strs,
     const double *nmeapos, prcopt_t *prcopt,
     solopt_t *solopt, stream_t *moni)
 {
-    gtime_t time, time0 = {0, 0.0};
-    int i, j, rw;
+    gtime_t time;
+    gtime_t time0 = {0, 0.0};
+    int i;
+    int j;
+    int rw;
 
     tracet(3, "rtksvrstart: cycle=%d buffsize=%d navsel=%d nmeacycle=%d nmeareq=%d\n",
         cycle, buffsize, navsel, nmeacycle, nmeareq);
 
-    if (svr->state) return 0;
+    if (svr->state)
+        {
+            return 0;
+        }
 
     strinitcom();
     svr->cycle = cycle > 1 ? cycle : 1;
     svr->nmeacycle = nmeacycle > 1000 ? nmeacycle : 1000;
     svr->nmeareq = nmeareq;
-    for (i = 0; i < 3; i++) svr->nmeapos[i] = nmeapos[i];
+    for (i = 0; i < 3; i++)
+        {
+            svr->nmeapos[i] = nmeapos[i];
+        }
     svr->buffsize = buffsize > 4096 ? buffsize : 4096;
-    for (i = 0; i < 3; i++) svr->format[i] = formats[i];
+    for (i = 0; i < 3; i++)
+        {
+            svr->format[i] = formats[i];
+        }
     svr->navsel = navsel;
     svr->nsbs = 0;
     svr->nsol = 0;
@@ -766,16 +928,30 @@ int rtksvrstart(rtksvr_t *svr, int cycle, int buffsize, int *strs,
                     tracet(1, "rtksvrstart: malloc error\n");
                     return 0;
                 }
-            for (j = 0; j < 10; j++) svr->nmsg[i][j] = 0;
-            for (j = 0; j < MAXOBSBUF; j++) svr->obs[i][j].n = 0;
+            for (j = 0; j < 10; j++)
+                {
+                    svr->nmsg[i][j] = 0;
+                }
+            for (j = 0; j < MAXOBSBUF; j++)
+                {
+                    svr->obs[i][j].n = 0;
+                }
 
             /* initialize receiver raw and rtcm control */
-            //init_raw (svr->raw +i);
+            // init_raw (svr->raw +i);
             init_rtcm(svr->rtcm + i);
 
             /* set receiver and rtcm option */
-            if (strlen(rcvopts[i]) < 256) strcpy(svr->raw[i].opt, rcvopts[i]);
-            if (strlen(rcvopts[i]) < 256) strcpy(svr->rtcm[i].opt, rcvopts[i]);
+            if (strlen(rcvopts[i]) < 256)
+                {
+                    std::strncpy(svr->raw[i].opt, rcvopts[i], 256);
+                    svr->raw[i].opt[255] = '\0';
+                }
+            if (strlen(rcvopts[i]) < 256)
+                {
+                    std::strncpy(svr->rtcm[i].opt, rcvopts[i], 256);
+                    svr->rtcm[i].opt[255] = '\0';
+                }
 
             /* connect dgps corrections */
             svr->rtcm[i].dgps = svr->nav.dgps;
@@ -799,9 +975,18 @@ int rtksvrstart(rtksvr_t *svr, int cycle, int buffsize, int *strs,
             svr->rtk.rb[i] = i < 3 ? prcopt->rb[i] : 0.0;
         }
     /* update navigation data */
-    for (i = 0; i < MAXSAT * 2; i++) svr->nav.eph[i].ttr = time0;
-    for (i = 0; i < NSATGLO * 2; i++) svr->nav.geph[i].tof = time0;
-    for (i = 0; i < NSATSBS * 2; i++) svr->nav.seph[i].tof = time0;
+    for (i = 0; i < MAXSAT * 2; i++)
+        {
+            svr->nav.eph[i].ttr = time0;
+        }
+    for (i = 0; i < NSATGLO * 2; i++)
+        {
+            svr->nav.geph[i].tof = time0;
+        }
+    for (i = 0; i < NSATSBS * 2; i++)
+        {
+            svr->nav.seph[i].tof = time0;
+        }
     updatenav(&svr->nav);
 
     /* set monitor stream */
@@ -811,10 +996,16 @@ int rtksvrstart(rtksvr_t *svr, int cycle, int buffsize, int *strs,
     for (i = 0; i < 8; i++)
         {
             rw = i < 3 ? STR_MODE_R : STR_MODE_W;
-            if (strs[i] != STR_FILE) rw |= STR_MODE_W;
+            if (strs[i] != STR_FILE)
+                {
+                    rw |= STR_MODE_W;
+                }
             if (!stropen(svr->stream + i, strs[i], rw, paths[i]))
                 {
-                    for (i--; i >= 0; i--) strclose(svr->stream + i);
+                    for (i--; i >= 0; i--)
+                        {
+                            strclose(svr->stream + i);
+                        }
                     return 0;
                 }
             /* set initial time for rtcm and raw */
@@ -832,7 +1023,10 @@ int rtksvrstart(rtksvr_t *svr, int cycle, int buffsize, int *strs,
     /* write start commands to input streams */
     for (i = 0; i < 3; i++)
         {
-            if (cmds[i]) strsendcmd(svr->stream + i, cmds[i]);
+            if (cmds[i])
+                {
+                    strsendcmd(svr->stream + i, cmds[i]);
+                }
         }
     /* write solution header to solution streams */
     for (i = 3; i < 5; i++)
@@ -842,7 +1036,10 @@ int rtksvrstart(rtksvr_t *svr, int cycle, int buffsize, int *strs,
     /* create rtk server thread */
     if (pthread_create(&svr->thread, nullptr, rtksvrthread, svr))
         {
-            for (i = 0; i < MAXSTRRTK; i++) strclose(svr->stream + i);
+            for (i = 0; i < MAXSTRRTK; i++)
+                {
+                    strclose(svr->stream + i);
+                }
             return 0;
         }
     return 1;
@@ -868,7 +1065,10 @@ void rtksvrstop(rtksvr_t *svr, char **cmds)
     rtksvrlock(svr);
     for (i = 0; i < 3; i++)
         {
-            if (cmds[i]) strsendcmd(svr->stream + i, cmds[i]);
+            if (cmds[i])
+                {
+                    strsendcmd(svr->stream + i, cmds[i]);
+                }
         }
     rtksvrunlock(svr);
 
@@ -896,7 +1096,10 @@ int rtksvropenstr(rtksvr_t *svr, int index, int str, const char *path,
 {
     tracet(3, "rtksvropenstr: index=%d str=%d path=%s\n", index, str, path);
 
-    if (index < 3 || index > 7 || !svr->state) return 0;
+    if (index < 3 || index > 7 || !svr->state)
+        {
+            return 0;
+        }
 
     rtksvrlock(svr);
 
@@ -935,7 +1138,10 @@ void rtksvrclosestr(rtksvr_t *svr, int index)
 {
     tracet(3, "rtksvrclosestr: index=%d\n", index);
 
-    if (index < 3 || index > 7 || !svr->state) return;
+    if (index < 3 || index > 7 || !svr->state)
+        {
+            return;
+        }
 
     rtksvrlock(svr);
 
@@ -961,11 +1167,16 @@ void rtksvrclosestr(rtksvr_t *svr, int index)
 int rtksvrostat(rtksvr_t *svr, int rcv, gtime_t *time, int *sat,
     double *az, double *el, int **snr, int *vsat)
 {
-    int i, j, ns;
+    int i;
+    int j;
+    int ns;
 
     tracet(4, "rtksvrostat: rcv=%d\n", rcv);
 
-    if (!svr->state) return 0;
+    if (!svr->state)
+        {
+            return 0;
+        }
     rtksvrlock(svr);
     ns = svr->obs[rcv][0].n;
     if (ns > 0)
@@ -1005,7 +1216,8 @@ int rtksvrostat(rtksvr_t *svr, int rcv, gtime_t *time, int *sat,
 void rtksvrsstat(rtksvr_t *svr, int *sstat, char *msg)
 {
     int i;
-    char s[MAXSTRMSG], *p = msg;
+    char s[MAXSTRMSG];
+    char *p = msg;
 
     tracet(4, "rtksvrsstat:\n");
 
@@ -1013,7 +1225,10 @@ void rtksvrsstat(rtksvr_t *svr, int *sstat, char *msg)
     for (i = 0; i < MAXSTRRTK; i++)
         {
             sstat[i] = strstat(svr->stream + i, s);
-            if (*s) p += sprintf(p, "(%d) %s ", i + 1, s);
+            if (*s)
+                {
+                    p += std::snprintf(p, MAXSTRMSG, "(%d) %s ", i + 1, s);
+                }
         }
     rtksvrunlock(svr);
 }
