@@ -5,29 +5,18 @@
  *          <li> Andres Cecilia, 2014. a.cecilia.luque(at)gmail.com
  *          </ul>
  *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
  *
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 /*!
@@ -68,8 +57,8 @@ static inline void volk_gnsssdr_32fc_convert_8ic_generic(lv_8sc_t* outputVector,
 {
     float* inputVectorPtr = (float*)inputVector;
     int8_t* outputVectorPtr = (int8_t*)outputVector;
-    const float min_val = (float)SCHAR_MIN;
-    const float max_val = (float)SCHAR_MAX;
+    const float min_val = (float)INT8_MIN;
+    const float max_val = (float)INT8_MAX;
     float aux;
     unsigned int i;
     for (i = 0; i < num_points * 2; i++)
@@ -95,8 +84,8 @@ static inline void volk_gnsssdr_32fc_convert_8ic_u_avx2(lv_8sc_t* outputVector,
     float* inputVectorPtr = (float*)inputVector;
     int8_t* outputVectorPtr = (int8_t*)outputVector;
 
-    const float min_val = (float)SCHAR_MIN;
-    const float max_val = (float)SCHAR_MAX;
+    const float min_val = (float)INT8_MIN;
+    const float max_val = (float)INT8_MAX;
     float aux;
     unsigned int i;
 
@@ -169,8 +158,8 @@ static inline void volk_gnsssdr_32fc_convert_8ic_a_avx2(lv_8sc_t* outputVector,
     float* inputVectorPtr = (float*)inputVector;
     int8_t* outputVectorPtr = (int8_t*)outputVector;
 
-    const float min_val = (float)SCHAR_MIN;
-    const float max_val = (float)SCHAR_MAX;
+    const float min_val = (float)INT8_MIN;
+    const float max_val = (float)INT8_MAX;
     float aux;
     unsigned int i;
 
@@ -243,8 +232,8 @@ static inline void volk_gnsssdr_32fc_convert_8ic_u_sse2(lv_8sc_t* outputVector,
     float* inputVectorPtr = (float*)inputVector;
     int8_t* outputVectorPtr = (int8_t*)outputVector;
 
-    const float min_val = (float)SCHAR_MIN;
-    const float max_val = (float)SCHAR_MAX;
+    const float min_val = (float)INT8_MIN;
+    const float max_val = (float)INT8_MAX;
     float aux;
     unsigned int i;
 
@@ -313,8 +302,8 @@ static inline void volk_gnsssdr_32fc_convert_8ic_a_sse2(lv_8sc_t* outputVector,
     float* inputVectorPtr = (float*)inputVector;
     int8_t* outputVectorPtr = (int8_t*)outputVector;
 
-    const float min_val = (float)SCHAR_MIN;
-    const float max_val = (float)SCHAR_MAX;
+    const float min_val = (float)INT8_MIN;
+    const float max_val = (float)INT8_MAX;
     float aux;
     unsigned int i;
 
@@ -382,8 +371,8 @@ static inline void volk_gnsssdr_32fc_convert_8ic_neon(lv_8sc_t* outputVector, co
 
     float32_t* inputVectorPtr = (float32_t*)inputVector;
     int8_t* outputVectorPtr = (int8_t*)outputVector;
-    const float32_t max_val_f = (float32_t)SCHAR_MAX;
-    const float32_t min_val_f = (float32_t)SCHAR_MIN;
+    const float32_t max_val_f = (float32_t)INT8_MAX;
+    const float32_t min_val_f = (float32_t)INT8_MIN;
     float32_t aux;
     unsigned int i;
 
