@@ -1,29 +1,19 @@
 /*
- * Copyright (C) 2010-2018 (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2019 (see AUTHORS file for a list of contributors)
+ *
+ * GNSS-SDR is a software-defined Global Navigation Satellite Systems receiver
  *
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
 
 #include "kernel_tests.h"                       // for init_test_list
 #include "qa_utils.h"                           // for volk_gnsssdr_test_case_t, volk_gnsssdr_test_results_t
 #include "volk_gnsssdr/volk_gnsssdr_complex.h"  // for lv_32fc_t
-#include <cstdbool>                             // for bool, false, true
 #include <fstream>                              // IWYU pragma: keep
-#include <iostream>                             // for operator<<, basic_ostream, endl, char...
+#include <iostream>                             // for operator<<, basic_ostream, char...
 #include <map>                                  // for map, map<>::iterator, _Rb_tree_iterator
 #include <sstream>                              // for stringstream
 #include <string>                               // for string, operator<<
@@ -53,7 +43,7 @@ int main(int argc, char* argv[])
             ss << argv[1];
             if (ss.fail())
                 {
-                    std::cerr << "Test name not correctly set." << std::endl;
+                    std::cerr << "Test name not correctly set.\n";
                     return 0;
                 }
             for (unsigned int ii = 0; ii < test_cases.size(); ++ii)
@@ -74,7 +64,7 @@ int main(int argc, char* argv[])
                                 }
                         }
                 }
-            std::cerr << "Did not run a test for kernel: " << std::string(argv[1]) << " !" << std::endl;
+            std::cerr << "Did not run a test for kernel: " << std::string(argv[1]) << " !\n";
             return 0;
         }
     else
@@ -93,13 +83,13 @@ int main(int argc, char* argv[])
                     catch (...)
                         {
                             // TODO: what exceptions might we need to catch and how do we handle them?
-                            std::cerr << "Exception found on kernel: " << test_case.name() << std::endl;
+                            std::cerr << "Exception found on kernel: " << test_case.name() << '\n';
                             qa_result = false;
                         }
 
                     if (qa_result)
                         {
-                            std::cerr << "Failure on " << test_case.name() << std::endl;
+                            std::cerr << "Failure on " << test_case.name() << '\n';
                             qa_failures.push_back(test_case.name());
                         }
                 }
@@ -109,13 +99,13 @@ int main(int argc, char* argv[])
 
             // Summarize QA results
             std::cerr << "Kernel QA finished: " << qa_failures.size() << " failures out of "
-                      << test_cases.size() << " tests." << std::endl;
+                      << test_cases.size() << " tests.\n";
             if (qa_failures.size() > 0)
                 {
-                    std::cerr << "The following kernels failed QA:" << std::endl;
+                    std::cerr << "The following kernels failed QA:\n";
                     for (unsigned int ii = 0; ii < qa_failures.size(); ++ii)
                         {
-                            std::cerr << "    " << qa_failures[ii] << std::endl;
+                            std::cerr << "    " << qa_failures[ii] << '\n';
                         }
                     qa_ret_val = 1;
                 }
@@ -133,17 +123,17 @@ void print_qa_xml(std::vector<volk_gnsssdr_test_results_t> results, unsigned int
     std::ofstream qa_file;
     qa_file.open(".unittest/kernels.xml");
 
-    qa_file << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>" << std::endl;
+    qa_file << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
     qa_file << "<testsuites name=\"kernels\" "
             << "tests=\"" << results.size() << "\" "
-            << "failures=\"" << nfails << "\" id=\"1\">" << std::endl;
+            << "failures=\"" << nfails << "\" id=\"1\">\n";
 
     // Results are in a vector by kernel. Each element has a result
     // map containing time and arch name with test result
     for (unsigned int ii = 0; ii < results.size(); ++ii)
         {
             volk_gnsssdr_test_results_t result = results[ii];
-            qa_file << "  <testsuite name=\"" << result.name << "\">" << std::endl;
+            qa_file << "  <testsuite name=\"" << result.name << "\">\n";
 
             std::map<std::string, volk_gnsssdr_test_time_t>::iterator kernel_time_pair;
             for (kernel_time_pair = result.results.begin(); kernel_time_pair != result.results.end(); ++kernel_time_pair)
@@ -151,16 +141,16 @@ void print_qa_xml(std::vector<volk_gnsssdr_test_results_t> results, unsigned int
                     volk_gnsssdr_test_time_t test_time = kernel_time_pair->second;
                     qa_file << "    <testcase name=\"" << test_time.name << "\" "
                             << "classname=\"" << result.name << "\" "
-                            << "time=\"" << test_time.time << "\">" << std::endl;
+                            << "time=\"" << test_time.time << "\">\n";
                     if (!test_time.pass)
                         qa_file << "      <failure "
                                 << "message=\"fail on arch " << test_time.name << "\">"
-                                << "</failure>" << std::endl;
-                    qa_file << "    </testcase>" << std::endl;
+                                << "</failure>\n";
+                    qa_file << "    </testcase>\n";
                 }
-            qa_file << "  </testsuite>" << std::endl;
+            qa_file << "  </testsuite>\n";
         }
 
-    qa_file << "</testsuites>" << std::endl;
+    qa_file << "</testsuites>\n";
     qa_file.close();
 }
