@@ -4,56 +4,59 @@
  * to a ObservablesInterface
  * \author Javier Arribas, 2011. jarribas(at)cttc.es
  *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
  *
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
-
 #include "hybrid_observables.h"
 #include "configuration_interface.h"
+#include "gnss_sdr_flags.h"
+#include "obs_conf.h"
 #include <glog/logging.h>
+#include <ostream>  // for operator<<
 
-
-using google::LogMessage;
-
-HybridObservables::HybridObservables(ConfigurationInterface* configuration,
+HybridObservables::HybridObservables(const ConfigurationInterface* configuration,
     const std::string& role, unsigned int in_streams, unsigned int out_streams) : role_(role), in_streams_(in_streams), out_streams_(out_streams)
 {
-    std::string default_dump_filename = "./observables.dat";
+    const std::string default_dump_filename("./observables.dat");
     DLOG(INFO) << "role " << role;
     dump_ = configuration->property(role + ".dump", false);
     dump_mat_ = configuration->property(role + ".dump_mat", true);
     dump_filename_ = configuration->property(role + ".dump_filename", default_dump_filename);
 
-    observables_ = hybrid_make_observables_cc(in_streams_, out_streams_, dump_, dump_mat_, dump_filename_);
+    Obs_Conf conf;
+
+    conf.dump = dump_;
+    conf.dump_mat = dump_mat_;
+    conf.dump_filename = dump_filename_;
+    conf.nchannels_in = in_streams_;
+    conf.nchannels_out = out_streams_;
+    conf.enable_carrier_smoothing = configuration->property(role + ".enable_carrier_smoothing", conf.enable_carrier_smoothing);
+
+    if (FLAGS_carrier_smoothing_factor == DEFAULT_CARRIER_SMOOTHING_FACTOR)
+        {
+            conf.smoothing_factor = configuration->property(role + ".smoothing_factor", conf.smoothing_factor);
+        }
+
+    if (conf.enable_carrier_smoothing == true)
+        {
+            LOG(INFO) << "Observables carrier smoothing enabled with smoothing factor " << conf.smoothing_factor;
+        }
+    observables_ = hybrid_observables_gs_make(conf);
     DLOG(INFO) << "Observables block ID (" << observables_->unique_id() << ")";
 }
 
 
-HybridObservables::~HybridObservables() = default;
-
-
 void HybridObservables::connect(gr::top_block_sptr top_block)
 {
     if (top_block)
