@@ -4,29 +4,18 @@
  * to a SignalConditionerInterface
  * \author Carlos Aviles, 2010. carlos.avilesr(at)googlemail.com
  *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
  *
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 #include "direct_resampler_conditioner.h"
@@ -36,29 +25,27 @@
 #include "direct_resampler_conditioner_cs.h"
 #include <glog/logging.h>
 #include <gnuradio/blocks/file_sink.h>
-#include <volk/volk.h>
+#include <volk/volk.h>  // for lv_8sc_t
 #include <cmath>
 #include <cstdint>
 #include <limits>
 
-using google::LogMessage;
 
 DirectResamplerConditioner::DirectResamplerConditioner(
-    ConfigurationInterface* configuration, const std::string& role,
+    const ConfigurationInterface* configuration, const std::string& role,
     unsigned int in_stream, unsigned int out_stream) : role_(role), in_stream_(in_stream), out_stream_(out_stream)
 {
-    std::string default_item_type = "short";
-    std::string default_dump_file = "./data/signal_conditioner.dat";
-    double fs_in_deprecated, fs_in;
-    fs_in_deprecated = configuration->property("GNSS-SDR.internal_fs_hz", 2048000.0);
-    fs_in = configuration->property("GNSS-SDR.internal_fs_sps", fs_in_deprecated);
+    const std::string default_item_type("short");
+    const std::string default_dump_file("./data/signal_conditioner.dat");
+    const double fs_in_deprecated = configuration->property("GNSS-SDR.internal_fs_hz", 2048000.0);
+    const double fs_in = configuration->property("GNSS-SDR.internal_fs_sps", fs_in_deprecated);
     sample_freq_in_ = configuration->property(role_ + ".sample_freq_in", 4000000.0);
     sample_freq_out_ = configuration->property(role_ + ".sample_freq_out", fs_in);
     if (std::fabs(fs_in - sample_freq_out_) > std::numeric_limits<double>::epsilon())
         {
             std::string aux_warn = "CONFIGURATION WARNING: Parameters GNSS-SDR.internal_fs_sps and " + role_ + ".sample_freq_out are not set to the same value!";
             LOG(WARNING) << aux_warn;
-            std::cout << aux_warn << std::endl;
+            std::cout << aux_warn << '\n';
         }
     item_type_ = configuration->property(role + ".item_type", default_item_type);
     dump_ = configuration->property(role + ".dump", false);
@@ -114,9 +101,6 @@ DirectResamplerConditioner::DirectResamplerConditioner(
 }
 
 
-DirectResamplerConditioner::~DirectResamplerConditioner() = default;
-
-
 void DirectResamplerConditioner::connect(gr::top_block_sptr top_block)
 {
     if (dump_)
