@@ -5,29 +5,18 @@
  * http://www.ifen.com/products/sx-scientific-gnss-solutions/nsr-software-receiver.html
  * \author Javier Arribas, 2013 jarribas(at)cttc.es
  *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
  *
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 #include "nsr_file_signal_source.h"
@@ -42,24 +31,27 @@
 #include <utility>
 
 
-using google::LogMessage;
-
-
-NsrFileSignalSource::NsrFileSignalSource(ConfigurationInterface* configuration,
+NsrFileSignalSource::NsrFileSignalSource(const ConfigurationInterface* configuration,
     const std::string& role, unsigned int in_streams, unsigned int out_streams,
-    boost::shared_ptr<gr::msg_queue> queue) : role_(role), in_streams_(in_streams), out_streams_(out_streams), queue_(std::move(queue))
+    Concurrent_Queue<pmt::pmt_t>* queue) : role_(role), in_streams_(in_streams), out_streams_(out_streams)
 {
-    std::string default_filename = "../data/my_capture.dat";
-    std::string default_item_type = "byte";
-    std::string default_dump_filename = "../data/my_capture_dump.dat";
+    const std::string default_filename("../data/my_capture.dat");
+    const std::string default_item_type("byte");
+    const std::string default_dump_filename("../data/my_capture_dump.dat");
 
-    samples_ = configuration->property(role + ".samples", 0);
-    sampling_frequency_ = configuration->property(role + ".sampling_frequency", 0);
+    samples_ = configuration->property(role + ".samples", static_cast<uint64_t>(0));
+    sampling_frequency_ = configuration->property(role + ".sampling_frequency", static_cast<int64_t>(0));
     filename_ = configuration->property(role + ".filename", default_filename);
 
     // override value with commandline flag, if present
-    if (FLAGS_signal_source != "-") filename_ = FLAGS_signal_source;
-    if (FLAGS_s != "-") filename_ = FLAGS_s;
+    if (FLAGS_signal_source != "-")
+        {
+            filename_ = FLAGS_signal_source;
+        }
+    if (FLAGS_s != "-")
+        {
+            filename_ = FLAGS_s;
+        }
 
     item_type_ = configuration->property(role + ".item_type", default_item_type);
     repeat_ = configuration->property(role + ".repeat", false);
@@ -84,20 +76,13 @@ NsrFileSignalSource::NsrFileSignalSource(ConfigurationInterface* configuration,
     catch (const std::exception& e)
         {
             std::cerr
-                << "The receiver was configured to work with a file signal source "
-                << std::endl
-                << "but the specified file is unreachable by GNSS-SDR."
-                << std::endl
-                << "Please modify your configuration file"
-                << std::endl
-                << "and point SignalSource.filename to a valid raw data file. Then:"
-                << std::endl
-                << "$ gnss-sdr --config_file=/path/to/my_GNSS_SDR_configuration.conf"
-                << std::endl
-                << "Examples of configuration files available at:"
-                << std::endl
-                << GNSSSDR_INSTALL_DIR "/share/gnss-sdr/conf/"
-                << std::endl;
+                << "The receiver was configured to work with a file signal source\n"
+                << "but the specified file is unreachable by GNSS-SDR.\n"
+                << "Please modify your configuration file\n"
+                << "and point SignalSource.filename to a valid raw data file. Then:\n"
+                << "$ gnss-sdr --config_file=/path/to/my_GNSS_SDR_configuration.conf\n"
+                << "Examples of configuration files available at:\n"
+                << GNSSSDR_INSTALL_DIR "/share/gnss-sdr/conf/\n";
 
             LOG(WARNING) << "file_signal_source: Unable to open the samples file "
                          << filename_.c_str() << ", exiting the program.";
@@ -123,34 +108,33 @@ NsrFileSignalSource::NsrFileSignalSource(ConfigurationInterface* configuration,
                 }
             else
                 {
-                    std::cout << "file_signal_source: Unable to open the samples file " << filename_.c_str() << std::endl;
+                    std::cout << "file_signal_source: Unable to open the samples file " << filename_.c_str() << '\n';
                     LOG(ERROR) << "file_signal_source: Unable to open the samples file " << filename_.c_str();
                 }
             std::streamsize ss = std::cout.precision();
             std::cout << std::setprecision(16);
-            std::cout << "Processing file " << filename_ << ", which contains " << size << " [bytes]" << std::endl;
+            std::cout << "Processing file " << filename_ << ", which contains " << size << " [bytes]\n";
             std::cout.precision(ss);
 
             if (size > 0)
                 {
                     int sample_packet_factor = 4;  // 1 byte -> 4 samples
                     samples_ = floor(static_cast<double>(size) / static_cast<double>(item_size())) * sample_packet_factor;
-                    samples_ = samples_ - ceil(0.002 * static_cast<double>(sampling_frequency_));  //process all the samples available in the file excluding the last 2 ms
+                    samples_ = samples_ - ceil(0.002 * static_cast<double>(sampling_frequency_));  // process all the samples available in the file excluding the last 2 ms
                 }
         }
 
     CHECK(samples_ > 0) << "File does not contain enough samples to process.";
-    double signal_duration_s;
-    signal_duration_s = static_cast<double>(samples_) * (1 / static_cast<double>(sampling_frequency_));
+    const double signal_duration_s = static_cast<double>(samples_) * (1 / static_cast<double>(sampling_frequency_));
     LOG(INFO) << "Total number samples to be processed= " << samples_ << " GNSS signal duration= " << signal_duration_s << " [s]";
-    std::cout << "GNSS signal recorded time to be processed: " << signal_duration_s << " [s]" << std::endl;
+    std::cout << "GNSS signal recorded time to be processed: " << signal_duration_s << " [s]\n";
 
-    valve_ = gnss_sdr_make_valve(sizeof(float), samples_, queue_);
+    valve_ = gnss_sdr_make_valve(sizeof(float), samples_, queue);
     DLOG(INFO) << "valve(" << valve_->unique_id() << ")";
 
     if (dump_)
         {
-            //sink_ = gr_make_file_sink(item_size_, dump_filename_.c_str());
+            // sink_ = gr_make_file_sink(item_size_, dump_filename_.c_str());
             sink_ = gr::blocks::file_sink::make(sizeof(float), dump_filename_.c_str());
             DLOG(INFO) << "file_sink(" << sink_->unique_id() << ")";
         }
@@ -178,9 +162,6 @@ NsrFileSignalSource::NsrFileSignalSource(ConfigurationInterface* configuration,
 }
 
 
-NsrFileSignalSource::~NsrFileSignalSource() = default;
-
-
 void NsrFileSignalSource::connect(gr::top_block_sptr top_block)
 {
     if (samples_ > 0)
@@ -298,7 +279,7 @@ void NsrFileSignalSource::disconnect(gr::top_block_sptr top_block)
 gr::basic_block_sptr NsrFileSignalSource::get_left_block()
 {
     LOG(WARNING) << "Left block of a signal source should not be retrieved";
-    //return gr_block_sptr();
+    // return gr_block_sptr();
     return gr::blocks::file_source::sptr();
 }
 
