@@ -4,9 +4,9 @@
  * and adapts it to a SignalSourceInterface.
  * \author Javier Arribas, 2015 jarribas(at)cttc.es
  *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2019  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
@@ -15,7 +15,7 @@
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 #include "two_bit_cpx_file_signal_source.h"
@@ -30,21 +30,21 @@
 #include <utility>
 
 
-TwoBitCpxFileSignalSource::TwoBitCpxFileSignalSource(ConfigurationInterface* configuration,
+TwoBitCpxFileSignalSource::TwoBitCpxFileSignalSource(
+    const ConfigurationInterface* configuration,
     const std::string& role,
     unsigned int in_streams,
     unsigned int out_streams,
-    const std::shared_ptr<Concurrent_Queue<pmt::pmt_t>>& queue) : role_(role),
-                                                                  in_streams_(in_streams),
-                                                                  out_streams_(out_streams),
-                                                                  queue_(queue)
+    Concurrent_Queue<pmt::pmt_t>* queue) : role_(role),
+                                           in_streams_(in_streams),
+                                           out_streams_(out_streams)
 {
-    std::string default_filename = "../data/my_capture.dat";
-    std::string default_item_type = "byte";
-    std::string default_dump_filename = "../data/my_capture_dump.dat";
+    const std::string default_filename("../data/my_capture.dat");
+    const std::string default_item_type("byte");
+    const std::string default_dump_filename("../data/my_capture_dump.dat");
 
-    samples_ = configuration->property(role + ".samples", 0);
-    sampling_frequency_ = configuration->property(role + ".sampling_frequency", 0);
+    samples_ = configuration->property(role + ".samples", static_cast<uint64_t>(0));
+    sampling_frequency_ = configuration->property(role + ".sampling_frequency", static_cast<int64_t>(0));
     filename_ = configuration->property(role + ".filename", default_filename);
 
     // override value with commandline flag, if present
@@ -81,20 +81,13 @@ TwoBitCpxFileSignalSource::TwoBitCpxFileSignalSource(ConfigurationInterface* con
     catch (const std::exception& e)
         {
             std::cerr
-                << "The receiver was configured to work with a file signal source "
-                << std::endl
-                << "but the specified file is unreachable by GNSS-SDR."
-                << std::endl
-                << "Please modify your configuration file"
-                << std::endl
-                << "and point SignalSource.filename to a valid raw data file. Then:"
-                << std::endl
-                << "$ gnss-sdr --config_file=/path/to/my_GNSS_SDR_configuration.conf"
-                << std::endl
-                << "Examples of configuration files available at:"
-                << std::endl
-                << GNSSSDR_INSTALL_DIR "/share/gnss-sdr/conf/"
-                << std::endl;
+                << "The receiver was configured to work with a file signal source\n"
+                << "but the specified file is unreachable by GNSS-SDR.\n"
+                << "Please modify your configuration file\n"
+                << "and point SignalSource.filename to a valid raw data file. Then:\n"
+                << "$ gnss-sdr --config_file=/path/to/my_GNSS_SDR_configuration.conf\n"
+                << "Examples of configuration files available at:\n"
+                << GNSSSDR_INSTALL_DIR "/share/gnss-sdr/conf/\n";
 
             LOG(WARNING) << "file_signal_source: Unable to open the samples file "
                          << filename_.c_str() << ", exiting the program.";
@@ -120,12 +113,12 @@ TwoBitCpxFileSignalSource::TwoBitCpxFileSignalSource(ConfigurationInterface* con
                 }
             else
                 {
-                    std::cout << "file_signal_source: Unable to open the samples file " << filename_.c_str() << std::endl;
+                    std::cout << "file_signal_source: Unable to open the samples file " << filename_.c_str() << '\n';
                     LOG(ERROR) << "file_signal_source: Unable to open the samples file " << filename_.c_str();
                 }
             std::streamsize ss = std::cout.precision();
             std::cout << std::setprecision(16);
-            std::cout << "Processing file " << filename_ << ", which contains " << size << " [bytes]" << std::endl;
+            std::cout << "Processing file " << filename_ << ", which contains " << size << " [bytes]\n";
             std::cout.precision(ss);
 
             if (size > 0)
@@ -137,12 +130,11 @@ TwoBitCpxFileSignalSource::TwoBitCpxFileSignalSource(ConfigurationInterface* con
         }
 
     CHECK(samples_ > 0) << "File does not contain enough samples to process.";
-    double signal_duration_s;
-    signal_duration_s = static_cast<double>(samples_) * (1 / static_cast<double>(sampling_frequency_));
+    const double signal_duration_s = static_cast<double>(samples_) * (1 / static_cast<double>(sampling_frequency_));
     LOG(INFO) << "Total number samples to be processed= " << samples_ << " GNSS signal duration= " << signal_duration_s << " [s]";
-    std::cout << "GNSS signal recorded time to be processed: " << signal_duration_s << " [s]" << std::endl;
+    std::cout << "GNSS signal recorded time to be processed: " << signal_duration_s << " [s]\n";
 
-    valve_ = gnss_sdr_make_valve(sizeof(gr_complex), samples_, queue_);
+    valve_ = gnss_sdr_make_valve(sizeof(gr_complex), samples_, queue);
     DLOG(INFO) << "valve(" << valve_->unique_id() << ")";
 
     if (dump_)
