@@ -4,35 +4,25 @@
  * \author Anthony Arnold, 2015. anthony.arnold(at)uqconnect.edu.au
  *
  * This file contains information taken from librtlsdr:
- *  http://git.osmocom.org/rtl-sdr/
- * -------------------------------------------------------------------------
+ *  https://git.osmocom.org/rtl-sdr
+ * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
  *
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 #ifndef GNSS_SDR_RTL_TCP_COMMANDS_H
 #define GNSS_SDR_RTL_TCP_COMMANDS_H
 
-#include <boost/asio/ip/tcp.hpp>
+#include <boost/asio/ip/tcp.hpp>        // for tcp, tcp::socket
+#include <boost/system/error_code.hpp>  // for error_code
 
 /// Command IDs for configuration rtl_tcp
 enum RTL_TCP_COMMAND
