@@ -5,45 +5,35 @@
  * \author Anthony Arnold, 2015. anthony.arnold(at)uqconnect.edu.au
  *
  * This file contains information taken from librtlsdr:
- *  http://git.osmocom.org/rtl-sdr/
- * -------------------------------------------------------------------------
+ *  https://git.osmocom.org/rtl-sdr
+ * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
  *
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 #include "rtl_tcp_dongle_info.h"
 #include <boost/foreach.hpp>
 #include <string>
+#include <vector>
 
 using boost::asio::ip::tcp;
 
-rtl_tcp_dongle_info::rtl_tcp_dongle_info() : tuner_type_(0), tuner_gain_count_(0)
+Rtl_Tcp_Dongle_Info::Rtl_Tcp_Dongle_Info() : tuner_type_(0), tuner_gain_count_(0)
 {
     std::memset(magic_, 0, sizeof(magic_));
 }
 
 
-boost::system::error_code rtl_tcp_dongle_info::read(boost::asio::ip::tcp::socket &socket)
+boost::system::error_code Rtl_Tcp_Dongle_Info::read(boost::asio::ip::tcp::socket &socket)
 {
     boost::system::error_code ec;
 
@@ -67,7 +57,7 @@ boost::system::error_code rtl_tcp_dongle_info::read(boost::asio::ip::tcp::socket
 }
 
 
-const char *rtl_tcp_dongle_info::get_type_name() const
+const char *Rtl_Tcp_Dongle_Info::get_type_name() const
 {
     switch (get_tuner_type())
         {
@@ -89,7 +79,7 @@ const char *rtl_tcp_dongle_info::get_type_name() const
 }
 
 
-double rtl_tcp_dongle_info::clip_gain(int gain) const
+double Rtl_Tcp_Dongle_Info::clip_gain(int gain) const
 {
     // the following gain values have been copied from librtlsdr
     // all gain values are expressed in tenths of a dB
@@ -121,7 +111,7 @@ double rtl_tcp_dongle_info::clip_gain(int gain) const
         }
 
     // clip
-    if (gains.size() == 0)
+    if (gains.empty())
         {
             // no defined gains to clip to
             return gain;
@@ -138,10 +128,7 @@ double rtl_tcp_dongle_info::clip_gain(int gain) const
                         {
                             return g;
                         }
-                    else
-                        {
-                            return last_stop;
-                        }
+                    return last_stop;
                 }
             last_stop = g;
         }
@@ -149,7 +136,7 @@ double rtl_tcp_dongle_info::clip_gain(int gain) const
 }
 
 
-bool rtl_tcp_dongle_info::is_valid() const
+bool Rtl_Tcp_Dongle_Info::is_valid() const
 {
     return std::memcmp(magic_, "RTL0", 4) == 0;
 }
