@@ -5,9 +5,9 @@
  * \author Javier Arribas 2013 jarribas(at)cttc.es,
  *  Mara Branzanti 2013. mara.branzanti(at)gmail.com
  *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2019  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
@@ -16,7 +16,7 @@
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 
@@ -26,6 +26,7 @@
 
 #include "galileo_telemetry_decoder_gs.h"
 #include "gnss_satellite.h"
+#include "gnss_synchro.h"
 #include "telemetry_decoder_interface.h"
 #include <gnuradio/runtime_types.h>  // for basic_block_sptr, top_block_sptr
 #include <cstddef>                   // for size_t
@@ -40,13 +41,21 @@ class ConfigurationInterface;
 class GalileoE1BTelemetryDecoder : public TelemetryDecoderInterface
 {
 public:
-    GalileoE1BTelemetryDecoder(ConfigurationInterface* configuration,
+    GalileoE1BTelemetryDecoder(
+        const ConfigurationInterface* configuration,
         const std::string& role,
         unsigned int in_streams,
         unsigned int out_streams);
 
     ~GalileoE1BTelemetryDecoder() = default;
 
+    void connect(gr::top_block_sptr top_block) override;
+    void disconnect(gr::top_block_sptr top_block) override;
+    gr::basic_block_sptr get_left_block() override;
+    gr::basic_block_sptr get_right_block() override;
+
+    void set_satellite(const Gnss_Satellite& satellite) override;
+
     inline std::string role() override
     {
         return role_;
@@ -60,33 +69,27 @@ public:
         return "Galileo_E1B_Telemetry_Decoder";
     }
 
-    void connect(gr::top_block_sptr top_block) override;
-    void disconnect(gr::top_block_sptr top_block) override;
-    gr::basic_block_sptr get_left_block() override;
-    gr::basic_block_sptr get_right_block() override;
-
-    void set_satellite(const Gnss_Satellite& satellite) override;
     inline void set_channel(int channel) override { telemetry_decoder_->set_channel(channel); }
+
     inline void reset() override
     {
         telemetry_decoder_->reset();
-        return;
     }
 
     inline size_t item_size() override
     {
-        return 0;
+        return sizeof(Gnss_Synchro);
     }
 
 private:
     galileo_telemetry_decoder_gs_sptr telemetry_decoder_;
     Gnss_Satellite satellite_;
-    int channel_;
-    bool dump_;
     std::string dump_filename_;
     std::string role_;
+    int channel_;
     unsigned int in_streams_;
     unsigned int out_streams_;
+    bool dump_;
 };
 
 #endif
