@@ -4,37 +4,30 @@
  * to a TelemetryDecoderInterface
  * \author Javier Arribas, 2015. jarribas(at)cttc.es
  *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
  *
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 
-#ifndef GNSS_SDR_GPS_L2C_TELEMETRY_DECODER_H_
-#define GNSS_SDR_GPS_L2C_TELEMETRY_DECODER_H_
+#ifndef GNSS_SDR_GPS_L2C_TELEMETRY_DECODER_H
+#define GNSS_SDR_GPS_L2C_TELEMETRY_DECODER_H
 
-#include "gps_l2c_telemetry_decoder_cc.h"
+#include "gnss_satellite.h"  // for Gnss_Satellite
+#include "gnss_synchro.h"
+#include "gps_l2c_telemetry_decoder_gs.h"
 #include "telemetry_decoder_interface.h"
+#include <gnuradio/runtime_types.h>  // for basic_block_sptr, top_block_sptr
+#include <cstddef>                   // for size_t
 #include <string>
 
 class ConfigurationInterface;
@@ -45,12 +38,13 @@ class ConfigurationInterface;
 class GpsL2CTelemetryDecoder : public TelemetryDecoderInterface
 {
 public:
-    GpsL2CTelemetryDecoder(ConfigurationInterface* configuration,
+    GpsL2CTelemetryDecoder(
+        const ConfigurationInterface* configuration,
         const std::string& role,
         unsigned int in_streams,
         unsigned int out_streams);
 
-    virtual ~GpsL2CTelemetryDecoder();
+    ~GpsL2CTelemetryDecoder() = default;
 
     inline std::string role() override
     {
@@ -69,26 +63,28 @@ public:
     gr::basic_block_sptr get_right_block() override;
 
     void set_satellite(const Gnss_Satellite& satellite) override;
+
     inline void set_channel(int channel) override { telemetry_decoder_->set_channel(channel); }
 
     inline void reset() override
     {
-        return;
+        telemetry_decoder_->reset();
     }
+
     inline size_t item_size() override
     {
-        return 0;
+        return sizeof(Gnss_Synchro);
     }
 
 private:
-    gps_l2c_telemetry_decoder_cc_sptr telemetry_decoder_;
+    gps_l2c_telemetry_decoder_gs_sptr telemetry_decoder_;
     Gnss_Satellite satellite_;
-    int channel_;
-    bool dump_;
     std::string dump_filename_;
     std::string role_;
+    int channel_;
     unsigned int in_streams_;
     unsigned int out_streams_;
+    bool dump_;
 };
 
 #endif
