@@ -4,38 +4,31 @@
  * to a TelemetryDecoderInterface
  * \author Daniel Fehr 2013. daniel.co(at)bluewin.ch
  *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
  *
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 
-#ifndef GNSS_SDR_SBAS_L1_TELEMETRY_DECODER_H_
-#define GNSS_SDR_SBAS_L1_TELEMETRY_DECODER_H_
+#ifndef GNSS_SDR_SBAS_L1_TELEMETRY_DECODER_H
+#define GNSS_SDR_SBAS_L1_TELEMETRY_DECODER_H
 
 
-#include "sbas_l1_telemetry_decoder_cc.h"
+#include "gnss_satellite.h"  // for Gnss_Satellite
+#include "gnss_synchro.h"
+#include "sbas_l1_telemetry_decoder_gs.h"
 #include "telemetry_decoder_interface.h"
+#include <gnuradio/runtime_types.h>  // for basic_block_sptr, top_block_sptr
+#include <cstddef>                   // for size_t
 #include <string>
 
 
@@ -47,12 +40,13 @@ class ConfigurationInterface;
 class SbasL1TelemetryDecoder : public TelemetryDecoderInterface
 {
 public:
-    SbasL1TelemetryDecoder(ConfigurationInterface* configuration,
+    SbasL1TelemetryDecoder(
+        const ConfigurationInterface* configuration,
         const std::string& role,
         unsigned int in_streams,
         unsigned int out_streams);
 
-    virtual ~SbasL1TelemetryDecoder();
+    ~SbasL1TelemetryDecoder() = default;
 
     inline std::string role() override
     {
@@ -73,27 +67,28 @@ public:
     gr::basic_block_sptr get_right_block() override;
 
     void set_satellite(const Gnss_Satellite& satellite) override;
+
     inline void set_channel(int channel) override { telemetry_decoder_->set_channel(channel); }
 
     inline void reset() override
     {
-        return;
+        telemetry_decoder_->reset();
     }
 
     inline size_t item_size() override
     {
-        return 0;
+        return sizeof(Gnss_Synchro);
     }
 
 private:
-    sbas_l1_telemetry_decoder_cc_sptr telemetry_decoder_;
+    sbas_l1_telemetry_decoder_gs_sptr telemetry_decoder_;
     Gnss_Satellite satellite_;
-    int channel_;
-    bool dump_;
     std::string dump_filename_;
     std::string role_;
+    int channel_;
     unsigned int in_streams_;
     unsigned int out_streams_;
+    bool dump_;
 };
 
 #endif
