@@ -11,33 +11,22 @@
  * A Software-Defined GPS and Galileo Receiver. A Single-Frequency
  * Approach, Birkhauser, 2007
  *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2012-2018  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2012-2020  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
  *
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
-#ifndef GNSS_SDR_GALILEO_E1_TCP_CONNECTOR_TRACKING_H_
-#define GNSS_SDR_GALILEO_E1_TCP_CONNECTOR_TRACKING_H_
+#ifndef GNSS_SDR_GALILEO_E1_TCP_CONNECTOR_TRACKING_H
+#define GNSS_SDR_GALILEO_E1_TCP_CONNECTOR_TRACKING_H
 
 #include "galileo_e1_tcp_connector_tracking_cc.h"
 #include "tracking_interface.h"
@@ -52,12 +41,13 @@ class ConfigurationInterface;
 class GalileoE1TcpConnectorTracking : public TrackingInterface
 {
 public:
-    GalileoE1TcpConnectorTracking(ConfigurationInterface* configuration,
+    GalileoE1TcpConnectorTracking(
+        const ConfigurationInterface* configuration,
         const std::string& role,
         unsigned int in_streams,
         unsigned int out_streams);
 
-    virtual ~GalileoE1TcpConnectorTracking();
+    ~GalileoE1TcpConnectorTracking() = default;
 
     inline std::string role() override
     {
@@ -107,4 +97,4 @@ private:
     unsigned int out_streams_;
 };
 
-#endif  // GNSS_SDR_GALILEO_E1_TCP_CONNECTOR_TRACKING_H_
+#endif  // GNSS_SDR_GALILEO_E1_TCP_CONNECTOR_TRACKING_H
