@@ -9,29 +9,18 @@
  * GPS and Galileo Receiver. A Single-Frequency Approach,
  * Birkhauser, 2007, Applied and Numerical Harmonic Analysis.
  *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
  *
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 #include "tracking_2nd_PLL_filter.h"
@@ -40,16 +29,16 @@
 void Tracking_2nd_PLL_filter::calculate_lopp_coef(float* tau1, float* tau2, float lbw, float zeta, float k)
 {
     // Solve natural frequency
-    float Wn = lbw * 8.0 * zeta / (4.0 * zeta * zeta + 1.0);
+    const float Wn = lbw * 8.0F * zeta / (4.0F * zeta * zeta + 1.0F);
     // solve for t1 & t2
     *tau1 = k / (Wn * Wn);
-    *tau2 = 2.0 * zeta / Wn;
+    *tau2 = 2.0F * zeta / Wn;
 }
 
 
 void Tracking_2nd_PLL_filter::set_PLL_BW(float pll_bw_hz)
 {
-    //Calculate filter coefficient values
+    // Calculate filter coefficient values
     d_pllnoisebandwidth = pll_bw_hz;
     calculate_lopp_coef(&d_tau1_carr, &d_tau2_carr, d_pllnoisebandwidth, d_plldampingratio, 0.25);  // Calculate filter coefficient values
 }
@@ -64,14 +53,13 @@ void Tracking_2nd_PLL_filter::initialize()
 
 
 /*
- * PLL second order FIR filter
+ * PLL second order IIR filter
  * Req Input in [Hz/Ti]
  * The output is in [Hz/s].
  */
 float Tracking_2nd_PLL_filter::get_carrier_nco(float PLL_discriminator)
 {
-    float carr_nco = d_old_carr_nco + (d_tau2_carr / d_tau1_carr) * (PLL_discriminator - d_old_carr_error) + (PLL_discriminator + d_old_carr_error) * (d_pdi_carr / (2.0 * d_tau1_carr));
-    //carr_nco = d_old_carr_nco + (d_tau2_carr/d_tau1_carr)*(PLL_discriminator - d_old_carr_error) + PLL_discriminator * (d_pdi_carr/d_tau1_carr);
+    float carr_nco = d_old_carr_nco + (d_tau2_carr / d_tau1_carr) * (PLL_discriminator - d_old_carr_error) + (PLL_discriminator + d_old_carr_error) * (d_pdi_carr / (2.0F * d_tau1_carr));
     d_old_carr_nco = carr_nco;
     d_old_carr_error = PLL_discriminator;
     return carr_nco;
@@ -80,24 +68,20 @@ float Tracking_2nd_PLL_filter::get_carrier_nco(float PLL_discriminator)
 
 Tracking_2nd_PLL_filter::Tracking_2nd_PLL_filter(float pdi_carr)
 {
-    //--- PLL variables --------------------------------------------------------
+    // PLL variables
     d_pdi_carr = pdi_carr;  // Summation interval for carrier
-    //d_plldampingratio = 0.65;
     d_plldampingratio = 0.7;
 }
 
 
 Tracking_2nd_PLL_filter::Tracking_2nd_PLL_filter()
 {
-    //--- PLL variables --------------------------------------------------------
+    // PLL variables
     d_pdi_carr = 0.001;  // Summation interval for carrier
     d_plldampingratio = 0.7;
 }
 
 
-Tracking_2nd_PLL_filter::~Tracking_2nd_PLL_filter() = default;
-
-
 void Tracking_2nd_PLL_filter::set_pdi(float pdi_carr)
 {
     d_pdi_carr = pdi_carr;  // Summation interval for code
