@@ -4,40 +4,30 @@
  * \author Carles Fernandez-Prades, 2014. cfernandez(at)cttc.es
  *
  *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
  *
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 #include "gnss_signal_processing.h"
 #include "gps_sdr_signal_processing.h"
+#include <array>
 #include <chrono>
 #include <complex>
-
+#include <vector>
 
 TEST(CodeGenerationTest, CodeGenGPSL1Test)
 {
-    std::complex<float>* _dest = new std::complex<float>[1023];
+    std::array<std::complex<float>, 1023> _dest{};
     signed int _prn = 1;
     unsigned int _chip_shift = 4;
 
@@ -54,9 +44,8 @@ TEST(CodeGenerationTest, CodeGenGPSL1Test)
     end = std::chrono::system_clock::now();
     std::chrono::duration<double> elapsed_seconds = end - start;
 
-    delete[] _dest;
     ASSERT_LE(0, elapsed_seconds.count());
-    std::cout << "Generation completed in " << elapsed_seconds.count() * 1e6 << " microseconds" << std::endl;
+    std::cout << "Generation completed in " << elapsed_seconds.count() * 1e6 << " microseconds\n";
 }
 
 
@@ -65,10 +54,10 @@ TEST(CodeGenerationTest, CodeGenGPSL1SampledTest)
     signed int _prn = 1;
     unsigned int _chip_shift = 4;
     double _fs = 8000000.0;
-    const signed int _codeFreqBasis = 1023000;  //Hz
+    const signed int _codeFreqBasis = 1023000;  // Hz
     const signed int _codeLength = 1023;
     int _samplesPerCode = round(_fs / static_cast<double>(_codeFreqBasis / _codeLength));
-    std::complex<float>* _dest = new std::complex<float>[_samplesPerCode];
+    std::vector<std::complex<float>> _dest(_samplesPerCode);
 
     int iterations = 1000;
 
@@ -83,9 +72,8 @@ TEST(CodeGenerationTest, CodeGenGPSL1SampledTest)
     end = std::chrono::system_clock::now();
     std::chrono::duration<double> elapsed_seconds = end - start;
 
-    delete[] _dest;
     ASSERT_LE(0, elapsed_seconds.count());
-    std::cout << "Generation completed in " << elapsed_seconds.count() * 1e6 << " microseconds" << std::endl;
+    std::cout << "Generation completed in " << elapsed_seconds.count() * 1e6 << " microseconds\n";
 }
 
 
@@ -93,10 +81,10 @@ TEST(CodeGenerationTest, ComplexConjugateTest)
 {
     double _fs = 8000000.0;
     double _f = 4000.0;
-    const signed int _codeFreqBasis = 1023000;  //Hz
+    const signed int _codeFreqBasis = 1023000;  // Hz
     const signed int _codeLength = 1023;
     int _samplesPerCode = round(_fs / static_cast<double>(_codeFreqBasis / _codeLength));
-    std::complex<float>* _dest = new std::complex<float>[_samplesPerCode];
+    std::vector<std::complex<float>> _dest(_samplesPerCode);
 
     int iterations = 1000;
 
@@ -105,13 +93,12 @@ TEST(CodeGenerationTest, ComplexConjugateTest)
 
     for (int i = 0; i < iterations; i++)
         {
-            complex_exp_gen_conj(_dest, _f, _fs, _samplesPerCode);
+            complex_exp_gen_conj(_dest, _f, _fs);
         }
 
     end = std::chrono::system_clock::now();
     std::chrono::duration<double> elapsed_seconds = end - start;
 
-    delete[] _dest;
     ASSERT_LE(0, elapsed_seconds.count());
-    std::cout << "Generation completed in " << elapsed_seconds.count() * 1e6 << " microseconds" << std::endl;
+    std::cout << "Generation completed in " << elapsed_seconds.count() * 1e6 << " microseconds\n";
 }
