@@ -4,40 +4,41 @@
  * \author Carles Fernandez-Prades, 2016. cfernandez(at)cttc.es
  *
  *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
  *
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
+#include "gnss_sdr_make_unique.h"
 #include "gnuplot_i.h"
 #include "test_flags.h"
-#include <boost/filesystem.hpp>
 #include <gnuradio/fft/fft.h>
 #include <algorithm>
 #include <chrono>
 #include <functional>
 #include <random>
 
+#if HAS_STD_FILESYSTEM
+#if HAS_STD_FILESYSTEM_EXPERIMENTAL
+#include <experimental/filesystem>
+namespace fs = std::experimental::filesystem;
+#else
+#include <filesystem>
+namespace fs = std::filesystem;
+#endif
+#else
+#include <boost/filesystem.hpp>
+namespace fs = boost::filesystem;
+#endif
 
 DEFINE_int32(fft_iterations_test, 1000, "Number of averaged iterations in FFT length timing test");
 DEFINE_bool(plot_fft_length_test, false, "Plots results of FFTLengthTest with gnuplot");
@@ -72,9 +73,8 @@ TEST(FFTLengthTest, MeasureExecutionTime)
 
     EXPECT_NO_THROW(
         for (it = fft_sizes_v.cbegin(); it != fft_sizes_v.cend(); ++it) {
-            gr::fft::fft_complex* d_fft;
             d_fft_size = *it;
-            d_fft = new gr::fft::fft_complex(d_fft_size, true);
+            auto d_fft = std::make_unique<gr::fft::fft_complex>(d_fft_size, true);
 
             std::generate_n(d_fft->get_inbuf(), d_fft_size, gen);
 
@@ -87,8 +87,7 @@ TEST(FFTLengthTest, MeasureExecutionTime)
             std::chrono::duration<double> elapsed_seconds = end - start;
             double exec_time = elapsed_seconds.count() / static_cast<double>(FLAGS_fft_iterations_test);
             execution_times.push_back(exec_time * 1e3);
-            std::cout << "FFT execution time for length=" << d_fft_size << " : " << exec_time << " [s]" << std::endl;
-            delete d_fft;
+            std::cout << "FFT execution time for length=" << d_fft_size << " : " << exec_time << " [s]\n";
 
             if ((d_fft_size & (d_fft_size - 1)) == 0)  // if it is a power of two
                 {
@@ -102,17 +101,17 @@ TEST(FFTLengthTest, MeasureExecutionTime)
             const std::string gnuplot_executable(FLAGS_gnuplot_executable);
             if (gnuplot_executable.empty())
                 {
-                    std::cout << "WARNING: Although the flag plot_fft_length_test has been set to TRUE," << std::endl;
-                    std::cout << "gnuplot has not been found in your system." << std::endl;
-                    std::cout << "Test results will not be plotted." << std::endl;
+                    std::cout << "WARNING: Although the flag plot_fft_length_test has been set to TRUE,\n";
+                    std::cout << "gnuplot has not been found in your system.\n";
+                    std::cout << "Test results will not be plotted.\n";
                 }
             else
                 {
                     try
                         {
-                            boost::filesystem::path p(gnuplot_executable);
-                            boost::filesystem::path dir = p.parent_path();
-                            std::string gnuplot_path = dir.native();
+                            fs::path p(gnuplot_executable);
+                            fs::path dir = p.parent_path();
+                            const std::string& gnuplot_path = dir.native();
                             Gnuplot::set_GNUPlotPath(gnuplot_path);
 
                             Gnuplot g1("linespoints");
@@ -151,11 +150,14 @@ TEST(FFTLengthTest, MeasureExecutionTime)
                             g2.set_style("points").plot_xy(powers_of_two, execution_times_powers_of_two, "Power of 2");
                             g2.savetops("FFT_execution_times");
                             g2.savetopdf("FFT_execution_times", 18);
-                            if (FLAGS_show_plots) g2.showonscreen();  // window output
+                            if (FLAGS_show_plots)
+                                {
+                                    g2.showonscreen();  // window output
+                                }
                         }
                     catch (const GnuplotException& ge)
                         {
-                            std::cout << ge.what() << std::endl;
+                            std::cout << ge.what() << '\n';
                         }
                 }
         }
