@@ -3,29 +3,18 @@
  * \brief Helper file for unit testing
  * \author Javier Arribas, 2017. jarribas(at)cttc.es
  *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
  *
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 #ifndef GNSS_SDR_TRACKING_DUMP_READER_H
@@ -36,16 +25,16 @@
 #include <string>
 #include <vector>
 
-class tracking_dump_reader
+class Tracking_Dump_Reader
 {
 public:
-    ~tracking_dump_reader();
+    ~Tracking_Dump_Reader();
     bool read_binary_obs();
     bool restart();
     int64_t num_epochs();
     bool open_obs_file(std::string out_file);
 
-    //tracking dump variables
+    // tracking dump variables
     // VEPLVL
     float abs_VE;
     float abs_E;
@@ -90,4 +79,4 @@ private:
     std::ifstream d_dump_file;
 };
 
-#endif  //GNSS_SDR_TRACKING_DUMP_READER_H
+#endif  // GNSS_SDR_TRACKING_DUMP_READER_H
